# Generated by Django 2.2.8 on 2020-02-13 20:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0193_jednostka_dla_punktacji_dyscyplin"),
    ]

    operations = [
        migrations.DeleteModel(name="Sumy_Patent_View",),
        migrations.DeleteModel(name="Sumy_Praca_Doktorska_View",),
        migrations.DeleteModel(name="Sumy_Praca_Habilitacyjna_View",),
        migrations.DeleteModel(name="Sumy_View",),
        migrations.DeleteModel(name="Sumy_Wydawnictwo_Ciagle_View",),
        migrations.DeleteModel(name="Sumy_Wydawnictwo_Zwarte_View",),
    ]
