# Generated by Django 3.0.14 on 2021-07-13 23:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0017_publikacjainstytucji_usertype"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="oswiadczenieinstytucji",
            options={
                "verbose_name": "Oświadczenie instytucji",
                "verbose_name_plural": "Oświadczenia instytucji",
            },
        ),
        migrations.AlterModelOptions(
            name="publikacjainstytucji",
            options={
                "verbose_name": "Publikacja instytucji",
                "verbose_name_plural": "Publikacje instytucji",
            },
        ),
        migrations.AlterUniqueTogether(
            name="oswiadczenieinstytucji",
            unique_together={("publicationId", "institutionId", "personId")},
        ),
    ]
