# Generated by Django 3.0.14 on 2021-06-05 19:28

from django.db import migrations

import bpp.models.dyscyplina_naukowa


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0271_auto_20210530_0225"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dyscyplina_naukowa",
            name="kod",
            field=bpp.models.dyscyplina_naukowa.KodDyscyplinyField(
                max_length=20,
                unique=True,
                validators=[
                    bpp.models.dyscyplina_naukowa.waliduj_format_kodu_numer,
                    bpp.models.dyscyplina_naukowa.waliduj_format_kodu_numer,
                    bpp.models.dyscyplina_naukowa.waliduj_format_kodu_numer,
                ],
            ),
        ),
    ]
