# Generated by Django 3.0.11 on 2021-01-03 20:17

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0233_wiecej_doktoratow_dla_jednego"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0234_rekord_mat_nadrzedne")
        ),
        # Odbudowanie tabeli rekord_mat spowoduje skasowanie bpp_uczelnia_ewaluacja_view,
        # stąd potrzeba zaciągnąć ten plik z poprzednich migracji:
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0207_uczelnia_analiza_view")
        ),
    ]
