@import "settings_orange";
@import "common";
@import "checkbox";
@import 'foundation';

@include foundation-global-styles;
@include foundation-xy-grid-classes;
@include foundation-grid;
@include foundation-flex-grid;
@include foundation-flex-classes;
@include foundation-typography;
@include foundation-forms;
@include foundation-button;
@include foundation-accordion;
@include foundation-accordion-menu;
@include foundation-badge;
@include foundation-breadcrumbs;
@include foundation-button-group;
@include foundation-callout;
@include foundation-card;
@include foundation-close-button;
@include foundation-menu;
@include foundation-menu-icon;
@include foundation-drilldown-menu;
@include foundation-dropdown;
@include foundation-dropdown-menu;
@include foundation-responsive-embed;
@include foundation-label;
@include foundation-media-object;
@include foundation-off-canvas;
@include foundation-orbit;
@include foundation-pagination;
@include foundation-progress-bar;
@include foundation-slider;
@include foundation-sticky;
@include foundation-reveal;
@include foundation-switch;
@include foundation-table;
@include foundation-tabs;
@include foundation-thumbnail;
@include foundation-title-bar;
@include foundation-tooltip;
@include foundation-top-bar;
@include foundation-visibility-classes;
@include foundation-float-classes;

$info-color: #DEF3B6;

input[type=checkbox]:checked + label {
  background-image: url(/static/bpp/images/lite-red-check.png);
  background-position: 0 -15px;
}

.ui-state-focus {
  background: $primary-color !important;
  border: 1px white !important;
}

.select2-results__option--highlighted {
  background: $primary-color !important;
  color: white;
}