# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-06-29 16:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0144_wyrzuc_w_z_informacji'),
    ]

    operations = [
        migrations.AddField(
            model_name='uczelnia',
            name='wyszukiwanie_rekordy_na_strone_anonim',
            field=models.SmallIntegerField(default=200, help_text='Ilość rekordów w wyszukiwaniu powyżej której znika opcja"Pokaż wszystkie" i "Drukuj" dla użytkownika anonimowego. Nie jest zalecane ustawianie powyżej 500. ', verbose_name='Ilość rekordów na stronę - anonim'),
        ),
        migrations.AddField(
            model_name='uczelnia',
            name='wyszukiwanie_rekordy_na_strone_zalogowany',
            field=models.SmallIntegerField(default=5000, help_text='Ilość rekordów w wyszukiwaniu powyżej której znika opcja"Pokaż wszystkie" i "Drukuj" dla użytkownika zalogowanego. Nie jest zalecane ustawianie powyżej 5000. ', verbose_name='Ilość rekordów na stronę - anonim'),
        ),
    ]
