# Generated by Django 3.0.11 on 2021-02-01 12:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0234_rekord_mat_nadrzedne"),
    ]

    operations = [
        migrations.AddField(
            model_name="ukryj_status_korekty",
            name="podglad",
            field=models.BooleanField(
                default=True,
                help_text="Uniemożliwia podgląd prac na stronie szczegółów rekordu oraz uniemożliwia wyszukanie takich prac przez pole globalnego wyszukania.",
            ),
        ),
    ]
