# Generated by Django 3.0.14 on 2021-06-06 23:09

from django.db import migrations

import bpp.models.dyscyplina_naukowa
import bpp.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0275_jednostka_hier"),
    ]

    operations = [
        migrations.AddField(
            model_name="uczelnia",
            name="pokazuj_raport_uczelni",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="never",
                max_length=50,
                verbose_name="Pokazuj raport uczelni",
            ),
        ),
    ]
