# Generated by Django 3.0.14 on 2021-11-09 23:02

import django.db.models.deletion
from django.db import migrations, models

import ewaluacja2021.models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0309_auto_20211110_0000"),
        ("ewaluacja2021", "0006_auto_20211110_0000"),
    ]

    operations = [
        migrations.AlterField(
            model_name="zamowienienaraport",
            name="dyscyplina_naukowa",
            field=models.ForeignKey(
                limit_choices_to=ewaluacja2021.models.dyscypliny_naukowe_w_bazie,
                on_delete=django.db.models.deletion.CASCADE,
                to="bpp.Dyscyplina_Naukowa",
            ),
        ),
    ]
