# Generated by Django 2.1.10 on 2019-10-09 06:02

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0180_merge_20190910_2236'),
    ]

    operations = [
        migrations.CreateModel(
            name='Cache_Punktacja_Autora_Sum',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('pkdaut', models.DecimalField(decimal_places=4, max_digits=20)),
                ('slot', models.DecimalField(decimal_places=4, max_digits=20)),
                ('pkdautslot', models.FloatField()),
                ('pkdautsum', models.FloatField()),
                ('pkdautslotsum', models.FloatField()),
            ],
            options={
                'db_table': 'bpp_temporary_cpaq',
                'ordering': ('autor', 'dyscyplina', '-pkdautslot'),
                'managed': False,
            },
        ),
        migrations.CreateModel(
            name='Cache_Punktacja_Autora_Sum_Gruop',
            fields=[
                ('autor', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, primary_key=True, serialize=False, to='bpp.Autor')),
                ('pkdautsum', models.FloatField()),
                ('pkdautslotsum', models.FloatField()),
            ],
            options={
                'db_table': 'bpp_temporary_cpasg',
                'ordering': ('autor', 'dyscyplina'),
                'managed': False,
            },
        ),
    ]
