# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-23 21:18
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0101_openaccess_w_multiseek'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='patent',
            name='afiliowana',
        ),
        migrations.RemoveField(
            model_name='praca_doktorska',
            name='afiliowana',
        ),
        migrations.RemoveField(
            model_name='praca_habilitacyjna',
            name='afiliowana',
        ),
        migrations.RemoveField(
            model_name='wydawnictwo_ciagle',
            name='afiliowana',
        ),
        migrations.RemoveField(
            model_name='wydawnictwo_zwarte',
            name='afiliowana',
        ),
    ]
