# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-11-08 11:59
from __future__ import unicode_literals

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):
    dependencies = [
        ('bpp', '0111_autorzy_afiliacja_zatrudniony'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0112_fix_refresh_cache")
        ),

    ]
