{% if is_paginated %}
<ul class="pagination hide-for-print">
    {% if page_obj.has_previous %}
        <li class="pagination-previous"><a
                href="?page{{ page_suffix }}={{ page_obj.previous_page_number }}{{ getvars }}{{ hashtag }}">poprzednia</a>
        </li>
    {% else %}
        <li class="pagination-previous disabled">poprzednia</li>
    {% endif %}
    {% for page in pages %}
    {% if page %}
    {% ifequal page page_obj.number %}
    <li class="current">{{ page }}</li>
    {% else %}
    <li><a href="?page{{ page_suffix }}={{ page }}{{ getvars }}{{ hashtag }}">{{ page }}</a>
    </li>
    {% endifequal %}
    {% else %}
    <li class="ellipsis" aria-hidden="true"></li>
    {% endif %}
    {% endfor %}
    {% if page_obj.has_next %}
        <li class="pagination-next"><a href="?page{{ page_suffix }}={{ page_obj.next_page_number }}{{ getvars }}{{ hashtag }}">następna</a>
        </li>
    {% else %}
        <li class="pagination-next disabled">następna</li>
    {% endif %}
</ul>
{% endif %}
