# Generated by Django 3.0.14 on 2021-10-01 20:26

import denorm.fields
from django.db import migrations

import django.contrib.postgres.fields.jsonb


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0296_nulltest_szablonopisu"),
    ]

    operations = [
        migrations.AddField(
            model_name="wydawca",
            name="ile_aliasow",
            field=denorm.fields.CountField("wydawca_set", default=0),
        ),
        migrations.AddField(
            model_name="wydawca",
            name="lista_poziomow",
            field=django.contrib.postgres.fields.jsonb.JSONField(
                blank=True, editable=False, null=True
            ),
        ),
    ]
