{% spaceless %}
<table width="100%">
    <tr>
        <td width="50%">A. {{ a }}</td>
        <td>liczba: {{ data_a }}</td>
    </tr>
    <tr>
        <td>B. {{ b }}</td>
        <td>liczba: {{ data_b }}</td>
</tr>
</table>
{% endspaceless %}