# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-08 19:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0078_django110_py3k'),
    ]

    operations = [
        migrations.AddField(
            model_name='wydzial',
            name='skrot_nazwy',
            field=models.CharField(blank=True, help_text='Skrót nazwy wydziału, wersja czytelna, np. "Wydz. Lek."', max_length=250, null=True, unique=True),
        ),
    ]
