# Generated by Django 2.2.10 on 2020-03-04 21:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0199_alias_wydawcy_trigger"),
    ]

    operations = [
        migrations.AlterField(
            model_name="jednostka",
            name="skupia_pracownikow",
            field=models.BooleanField(
                db_index=True,
                default=True,
                help_text="Ta jednostka skupia osoby będące faktycznymi pracownikami uczelni. Odznacz dla jednostek\n         typu 'Studenci', 'Doktoranci', 'Pracownicy emerytowani' itp. Odznacz dla 'obcych' jednostek. ",
                verbose_name="Skupia pracowników",
            ),
        ),
        migrations.AlterField(
            model_name="patent_autor",
            name="afiliuje",
            field=models.BooleanField(
                default=True,
                help_text="Afiliuje\n    się do jednostki podanej w przypisaniu. Jednostka nie może być obcą. ",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle_autor",
            name="afiliuje",
            field=models.BooleanField(
                default=True,
                help_text="Afiliuje\n    się do jednostki podanej w przypisaniu. Jednostka nie może być obcą. ",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte_autor",
            name="afiliuje",
            field=models.BooleanField(
                default=True,
                help_text="Afiliuje\n    się do jednostki podanej w przypisaniu. Jednostka nie może być obcą. ",
            ),
        ),
    ]
