# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-14 07:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0081_konferencje'),
    ]

    operations = [
        migrations.AlterField(
            model_name='konferencja',
            name='miasto',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Miasto'),
        ),
        migrations.AlterField(
            model_name='konferencja',
            name='panstwo',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Państwo'),
        ),
        migrations.AlterField(
            model_name='konferencja',
            name='rozpoczecie',
            field=models.DateField(blank=True, null=True, verbose_name='Rozpoczęcie'),
        ),
        migrations.AlterField(
            model_name='konferencja',
            name='skrocona_nazwa',
            field=models.CharField(blank=True, db_index=True, max_length=250, null=True, verbose_name='Skrócona nazwa'),
        ),
        migrations.AlterField(
            model_name='konferencja',
            name='zakonczenie',
            field=models.DateField(blank=True, null=True, verbose_name='Zakończenie'),
        ),
    ]
