{% extends "bare.html" %}
{% load static static cache just_single_quotes bpp_version crispy_forms_tags %}

{% block extrahead %}
    {{ block.super }}

    {% load session_security_tags %}
    {% load l10n %}

    {% if request.user.is_authenticated %}
        {% include 'session_security/dialog.html' %}
        <script type="text/javascript">
            var sessionSecurity = new yourlabs.SessionSecurity({
                pingUrl: '{% url 'session_security_ping' %}',
                warnAfter: {{ request|warn_after|unlocalize }},
                expireAfter: {{ request|expire_after|unlocalize }},
                confirmFormDiscard: false
            });

            var messageAlertSound = null;
        </script>
    {% endif %}

{% endblock %}

{% block body %}
        {% load notifications %}
        <div id="messageTemplate" style="display: none;">
        {% verbatim messageTemplate %}
        <div data-closable
             data-url="{{ closeURL }}"
             class="ajax-on-close callout primary {{ cssClass }}{{^cssClass}}info{{/cssClass}}">
        {{#clickURL}}
        <a href="{{ clickURL }}">
        {{/clickURL}}
        {{{ text }}}
        {{#clickURL}}</a>{{/clickURL}}
            <button
                type="button"
                class="close-button"
                aria-label="Zamknij powiadomienie"
                data-close>
             <span aria-hidden="true">&times;</span>
             </button>

        </div>
        {% endverbatim messageTemplate %}
        </div>
        {# fix pycharm highlighting #}

    {% if request.user.is_authenticated %}
        {{ extraChannels|json_script:"extra-channels" }}
        <script type="text/javascript">
            $(document).ready(function () {
                bppNotifications.init("{% static "bpp/wav/alert.wav" %}",
                    document.getElementById('extra-channels').textContent);

                $(document).on('closed.zf', function (event) {
                    if ($(event.target).hasClass("ajax-on-close")) {
                        var url = $(event.target).data("url");
                        if (url) {
                            $.get(url);
                        }
                    }
                });

                {% if messages %}
                    {% for message in messages %}
                        bppNotifications.addMessage({
                            cssClass: '{{ message.level|message_level_to_css_class }}',
                            clickURL: '{{ message.url }}',
                            {% if message.pk %}
                                closeURL: '{% url "messages_extends:message_mark_read" message.pk %}',
                            {% endif %}
                            pk: '{{ message.pk }}',
                            text: '{{ message.message|just_single_quotes|safe }}',
                            sound: false
                        });
                    {% endfor %}
                {% endif %}

            });

        </script>
    {% else %}
{#        Użytkownik NIE jest autoryzowany -- wyrzuć mu za pomoca JScript (zeby wygladalo identycznie) #}
{#        listę statycznych komunikatów -- flash messages (tych co to pomiędzy requestami)... #}

        <script type="text/javascript">
            $(document).ready(function () {
                bppNotifications.init("{% static "bpp/wav/alert.wav" %}");

                {% if messages %}
                    {% for message in messages %}
                        bppNotifications.addMessage({
                            cssClass: '{{ message.level|message_level_to_css_class }}',
                            clickURL: '{{ message.url }}',
                            {% if message.pk %}
                                closeURL: '{% url "messages_extends:message_mark_read" message.pk %}',
                            {% endif %}
                            pk: '{{ message.pk }}',
                            text: '{{ message.message|just_single_quotes|safe }}',
                            sound: false
                        });
                    {% endfor %}
                {% endif %}
            });
        </script>

    {% endif %}

    <div class="title-bar" data-responsive-toggle="example-menu" data-hide-for="medium">
        <button class="menu-icon" type="button" data-toggle="example-menu"></button>
        <div class="title-bar-title hide-for-print">Menu</div>
    </div>

    <div class="grid-container-fluid hide-for-print" data-sticky-container>

        <div class="top-bar stacked-for-medium hide-for-print" id="example-menu" data-sticky data-options="marginTop:0;"
             style="width:100%;">
            <div class="top-bar-left">
                <ul class="dropdown menu" data-dropdown-menu>
                    <li class="menu-text" style="cursor:pointer;"
                        onclick="location.href='/';">
                        BPP
                    </li>
                    <li><a href="{% url "multiseek:index" %}"><i class="fi-magnifying-glass"></i> szukaj</a>
                    </li>
                    <li>
                        <a href="#"><i class="fi-list"></i> przeglądaj</a>
                        <ul class="menu vertical">
                            <li><a href="/">uczelnia</a></li>
                            <li><a href="{% url "bpp:browse_jednostki" %}">jednostki</a></li>
                            <li><a href="{% url "bpp:browse_autorzy" %}">autorzy</a></li>
                            <li><a href="{% url "bpp:browse_zrodla" %}">źródła</a></li>
                        </ul>
                    </li>
                    <li>
                        <a href="#"><i class="fi-graph-trend"></i> raporty</a>
                        <ul class="menu vertical">
                            {% load czy_pokazywac %}
                            {% czy_pokazywac raport_dla_komisji_centralnej %}
                                <li>
                                    <a href="{% url "bpp:raport_dla_komisji_centralnej" %}">raport
                                        dla Komisji Centralnej</a></li>
                            {% end_czy_pokazywac %}

                            {% load user_in_group %}

                            {% if ENABLE_NEW_REPORTS %}
                                {% czy_pokazywac raport_uczelni %}
                                    <li>
                                        <a href="{% url "nowe_raporty:uczelnia_form" %}">
                                            raport uczelni
                                        </a>
                                    </li>
                                {% end_czy_pokazywac %}
                                {% czy_pokazywac raport_wydzialow %}
                                    <li>
                                        <a href="{% url "nowe_raporty:wydzial_form" %}">
                                            raport wydziałów
                                        </a>
                                    </li>
                                {% end_czy_pokazywac %}
                                {% czy_pokazywac raport_jednostek %}
                                    <li>
                                        <a href="{% url "nowe_raporty:jednostka_form" %}">
                                            raport jednostek
                                        </a>
                                    </li>
                                {% end_czy_pokazywac %}
                                {% czy_pokazywac raport_autorow %}
                                    <li>
                                        <a href="{% url "nowe_raporty:autor_form" %}">
                                            raport autorów
                                        </a>
                                    </li>
                                {% end_czy_pokazywac %}
                            {% else %}
                                {% czy_pokazywac raport_jednostek %}
                                    <li>
                                        <a href="{% url "bpp:raport_jednostek_formularz" %}">raport
                                            jednostek</a></li>
                                {% end_czy_pokazywac %}
                                {% czy_pokazywac raport_autorow %}

                                    <li><a href="{% url "bpp:raport_autorow_formularz" %}">raport
                                        autorów</a></li>
                                {% end_czy_pokazywac %}
                            {% endif %}
                            {% czy_pokazywac ranking_autorow %}
                                <hr>
                                <li><a href="{% url "bpp:ranking_autorow_formularz" %}">ranking
                                    autorów</a></li>
                                <hr>
                            {% end_czy_pokazywac %}

                            {% czy_pokazywac raport_slotow_autor %}
                                <li><a href="{% url "raport_slotow:index" %}">raport slotów - autor</a></li>
                            {% end_czy_pokazywac %}
                            {% czy_pokazywac raport_slotow_zerowy  %}
                                <li><a href="{% url "raport_slotow:raport-slotow-zerowy" %}">raport slotów - zerowy</a>
                                </li>
                                <li><a href="{% url "raport_slotow:raport-slotow-zerowy-bez-5" %}">raport slotów -
                                    zerowy PK>5</a></li>
                            {% end_czy_pokazywac %}

                            {% czy_pokazywac raport_slotow_uczelnia %}
                                <li><a href="{% url "raport_slotow:lista-raport-slotow-uczelnia" %}">raport slotów -
                                    uczelnia</a></li>
                                <li><a href="{% url "raport_slotow:index-ewaluacja" %}">raport slotów - ewaluacja</a>
                                <li><a href="{% url "raport_slotow:index-upowaznienia" %}">raport ewaluacja - upoważnienia</a>
                                <li><a href="{% url "ewaluacja2021:lista-raportow3n" %}">raport ewaluacja - 3N</a>
                                </li>
                            {% end_czy_pokazywac %}


                        </ul>
                    </li>
                    {% if not request.user.is_anonymous  %}

                        {% if request.user.is_superuser or request.user|has_group:"wprowadzanie danych" %}
                            <li>
                                <a href="#">operacje</a>
                                <ul class="menu vertical">
                                    {% if request.user|has_group:"wprowadzanie danych" or request.user.is_superuser %}
                                        <li><a href="{% url "pbn_api:authorize" %}">autoryzuj PBN API</a></li>
                                        <li><a href="{% url "integrator2:main" %}">import danych</a></li>
                                        <li><a href="{% url "import_pracownikow:index" %}">import pracowników</a></li>
                                        <li><a href="{% url "ewaluacja2021:lista-importow" %}">import udziałów dla autorów</a>
                                        </li>
                                        <li><a href="{% url "import_list_if:index" %}">import list IF</a></li>
                                        <li><a href="{% url "import_dyscyplin:index" %}">import dyscyplin</a></li>
                                        <li><a href="{% url "admin:rozbieznosci_dyscyplin_rozbieznosciview_changelist" %}">
                                            rozbieżności dyscyplin</a></li>
                                        <li><a href="{% url "rozbieznosci_if:index" %}">rozbieżności
                                            punktacji IF</a></li>
                                    {% endif %}

                                    <li><a id="password-change-link" href="{% url "password_change" %}">zmiana hasła</a>
                                    </li>
                                </ul>
                            </li>
                        {% endif %}

                        {% if request.user.is_staff %}
                            <li><a target="_blank"
                                   href="{% url "admin:index" %}">redagowanie</a>
                            </li>
                        {% endif %}

                        <li><a target="_blank"
                               href="{% url "logout" %}">wyloguj</a>
                        </li>

                    {% endif %}

                    {% if request.user.is_anonymous %}
                        <li><a href="{% url "login_form" %}?next={{ request.get_full_path }}">
                            <i class="fi-lock"></i>
                            zaloguj</a></li>
                    {% endif %}


                </ul>
            </div>
            <div class="top-bar-right">
                <ul class="dropdown menu" data-dropdown-menu>
                    {% block global-nav %}
                        <li>
                            {% crispy global_nav_form %}
                            <script type="text/javascript">
                                $(document).ready(function () {
                                    $(':input[name$=global_nav_value]').on('change', function () {
                                        location.href = "/global-nav-redir/" + $(this).val() +
                                            "/?source=user";
                                    });
                                });
                            </script>
                        </li>
                    {% endblock %}

                </ul>
            </div>
        </div>
    </div>

    <div class="grid-container">
        {% block before-breadcrumbs %}{% endblock %}
        <div class="grid-x hide-for-small-only">
            <ul class="breadcrumbs hide-for-print" style="margin-top: 10px;">
                {% block breadcrumbs %}
                    <li><a href="/">Strona główna</a></li>
                {% endblock %}
            </ul>
        </div>

        <div class="grid-x">
            <div class="large-12 cell">

                <div id="messagesPlaceholder"></div>

                <div id="content">
                    {% if "test" in request.get_host %}

                        {# Najprostsza, naiwna identyfikacja serwera testowego - słowo 'test' w nazwie domeny. #}

                        <div class="hide-on-print callout alert">
                            <b>Serwer testowy</b>. Zmiany mogą zostać nadpisane zgodnie z ustawieniami aktualizacji.
                        </div>

                        <style>
                            body {
                                background-image: url("{% static "bpp/images/test_server_background.jpg" %}") !important;
                                background-size: 100%;
                                background-repeat: repeat-y;
                            }

                            #test-image-copyright {
                                display: block !important;
                            }
                        </style>
                    {% endif %}

                    {% if password_change_required %}
                        <div class="grid-x align-center">
                            <div class="large-6 medium-8 small-12 cell">

                                <div class='callout primary'>Twoje hasło uległo przeterminowaniu.
                                    Proszę, zmień je używając poniższego formularza.
                                </div>
                                <form action="." method="post">{% csrf_token %}
                                    {% crispy form %}{% if next %}
                                        <input type="hidden" name="next" value="{{ next }}"/>{% endif %}
                                </form>
                            </div>
                        </div>
                    {% else %}
                        {% block content %}
                        {% endblock %}
                    {% endif %}
                </div>
            </div>

            {% include "base_footer.html" %}

        </div>
        {% load cookielaw_tags %}
        {% cookielaw_banner %}
    </div>

    {% cache 3600 google %}
        {% if GOOGLE_ANALYTICS_PROPERTY_ID %}
            {% include "ga.html" %}
        {% endif %}
    {% endcache %}

{% endblock %}
