# Generated by Django 3.0.14 on 2021-07-13 20:35

from django.db import migrations

import django.contrib.postgres.fields.jsonb


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0015_auto_20210713_2234"),
    ]

    operations = [
        migrations.AlterField(
            model_name="publikacjainstytucji",
            name="snapshot",
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, null=True),
        ),
    ]
