{% if request.user.is_staff %}
    <div class="callout warning hide-for-print">
        <a target="_blank" href="{% url url pk %}"><i class="fi-page-edit"></i> otwórz do edycji</a>
    </div>
{% endif %}