# Generated by Django 3.0.14 on 2021-06-06 12:29

from django.db import migrations, models

import bpp.models.dyscyplina_naukowa


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0272_auto_20210605_2128"),
    ]

    operations = [
        migrations.AddField(
            model_name="jednostka",
            name="level",
            field=models.PositiveIntegerField(default=0, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="jednostka",
            name="lft",
            field=models.PositiveIntegerField(default=0, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="jednostka",
            name="rght",
            field=models.PositiveIntegerField(default=0, editable=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="jednostka",
            name="tree_id",
            field=models.PositiveIntegerField(db_index=True, default=0, editable=False),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="dyscyplina_naukowa",
            name="kod",
            field=bpp.models.dyscyplina_naukowa.KodDyscyplinyField(
                max_length=20,
                unique=True,
                validators=[
                    bpp.models.dyscyplina_naukowa.waliduj_format_kodu_numer,
                    bpp.models.dyscyplina_naukowa.waliduj_format_kodu_numer,
                    bpp.models.dyscyplina_naukowa.waliduj_format_kodu_numer,
                ],
            ),
        ),
    ]
