# Generated by Django 3.0.11 on 2021-01-25 01:56

import django.db.models.deletion
from django.db import migrations, models

import bpp.models.uczelnia


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0235_auto_20210125_0042"),
        ("raport_slotow", "0004_raportslotowuczelnia_raportslotowuczelniawiersz"),
    ]

    operations = [
        migrations.AddField(
            model_name="raportslotowuczelniawiersz",
            name="avg",
            field=models.DecimalField(
                decimal_places=4,
                default=0,
                max_digits=8,
                verbose_name="Średnio punktów dla autora na slot",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="raportslotowuczelnia",
            name="do_roku",
            field=models.IntegerField(
                default=bpp.models.uczelnia.UczelniaManager.do_roku_default
            ),
        ),
        migrations.AlterField(
            model_name="raportslotowuczelniawiersz",
            name="jednostka",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="bpp.Jednostka",
            ),
        ),
    ]
