# Generated by Django 3.0.9 on 2020-10-10 22:02

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0225_auto_20201007_1002"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0226_rekord_mat_status")
        ),
        # Odbudowanie tabeli rekord_mat spowoduje skasowanie bpp_uczelnia_ewaluacja_view,
        # stąd potrzeba zaciągnąć ten plik z poprzednich migracji:
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0207_uczelnia_analiza_view")
        ),
    ]
