# Generated by Django 3.0.14 on 2021-10-31 20:03

from django.db import migrations, models

import django.contrib.postgres.fields.jsonb


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Log",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("started_on", models.DateTimeField(auto_now_add=True)),
                ("finished_on", models.DateTimeField(blank=True, null=True)),
                ("exitcode", models.SmallIntegerField(blank=True, null=True)),
                ("command_name", models.TextField()),
                (
                    "args",
                    django.contrib.postgres.fields.jsonb.JSONField(
                        blank=True, null=True
                    ),
                ),
                (
                    "kwargs",
                    django.contrib.postgres.fields.jsonb.JSONField(
                        blank=True, null=True
                    ),
                ),
                ("stdout", models.TextField(blank=True, null=True)),
                ("stderr", models.TextField(blank=True, null=True)),
            ],
        ),
    ]
