# Generated by Django 3.0.14 on 2021-07-25 20:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0279_usun_ost_akt_pbn"),
    ]

    operations = [
        migrations.AlterField(
            model_name="charakter_formalny",
            name="rodzaj_pbn",
            field=models.PositiveSmallIntegerField(
                blank=True,
                choices=[
                    (None, "nie eksportuj do PBN"),
                    (1, "artykuł"),
                    (3, "książka"),
                    (2, "rozdział"),
                    (4, "postępowanie"),
                ],
                default=None,
                help_text="Pole określające, czy wydawnictwa posiadające dany charakter formalny zostaną włączone\n        do eksportu PBN jako artykuły, rozdziały czy książki. ",
                null=True,
                verbose_name="Rodzaj dla PBN",
            ),
        ),
    ]
