/* CSS Created by CSS CHECKBOX */
/**********************************/
/**** www.CSScheckbox.com *********/

/*general styles for all CSS Checkboxes*/
label {
-webkit-touch-callout: none;
-webkit-user-select: none;
-khtml-user-select: none;
-moz-user-select: none;
-ms-user-select: none;
user-select: none;
}

input[type=checkbox] {
	position: absolute;
    overflow: hidden;
    clip: rect(0 0 0 0);
    height:1px;
    width:1px;
    margin:-1px;
    padding:0;
    border:0;
}

input[type=checkbox] + label {
	padding-left:20px;
	display:inline-block;
	background-repeat:no-repeat;
	background-position: 0 3px;
	//font-size:15px;
	vertical-align:middle;
	cursor:pointer;
	background-image: url(/static/bpp/images/no-check.png);
}
