# Generated by Django 3.0.11 on 2021-04-06 02:56

from django.db import migrations, models

import django.contrib.postgres.fields.jsonb


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0006_sciencist"),
    ]

    operations = [
        migrations.CreateModel(
            name="Publication",
            fields=[
                ("created_on", models.DateTimeField(auto_now_add=True)),
                ("last_updated_on", models.DateTimeField(auto_now=True)),
                (
                    "mongoId",
                    models.CharField(max_length=32, primary_key=True, serialize=False),
                ),
                ("status", models.CharField(db_index=True, max_length=32)),
                ("verificationLevel", models.CharField(max_length=32)),
                ("verified", models.BooleanField(default=False)),
                ("versions", django.contrib.postgres.fields.jsonb.JSONField()),
            ],
            options={
                "abstract": False,
            },
        ),
    ]
