# Generated by Django 3.0.14 on 2021-11-22 00:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ewaluacja2021", "0007_auto_20211110_0002"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="zamowienienaraport",
            options={"ordering": ("-ostatnio_zmodyfikowany",)},
        ),
        migrations.AlterField(
            model_name="zamowienienaraport",
            name="rodzaj",
            field=models.CharField(
                choices=[
                    ("plecakowy", "plecakowy"),
                    ("plecakowy_bez_limitu", "plecakowy bez limitu na uczelnię"),
                    ("genetyczny", "genetyczny"),
                    ("genetyczny_z_odpinaniem", "genetyczny z odpinaniem"),
                ],
                max_length=25,
                verbose_name="Rodzaj algorytmu",
            ),
        ),
    ]
