# Generated by Django 3.0.11 on 2021-03-07 10:10

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0241_auto_20210228_1916"),
    ]

    operations = [
        migrations.CreateModel(
            name="Grupa_Pracownicza",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("nazwa", models.CharField(max_length=512, unique=True)),
            ],
            options={
                "verbose_name": "grupa pracownicza",
                "verbose_name_plural": "grupy pracownicze",
                "ordering": ["nazwa"],
            },
        ),
        migrations.CreateModel(
            name="Wymiar_Etatu",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("nazwa", models.CharField(max_length=512, unique=True)),
            ],
            options={
                "verbose_name": "wymiar etatu",
                "verbose_name_plural": "wymiary etatów",
                "ordering": ["nazwa"],
            },
        ),
        migrations.AddField(
            model_name="autor_jednostka",
            name="grupa_pracownicza",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="bpp.Grupa_Pracownicza",
            ),
        ),
        migrations.AddField(
            model_name="autor_jednostka",
            name="wymiar_etatu",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="bpp.Wymiar_Etatu",
            ),
        ),
    ]
