# Generated by Django 2.1.7 on 2019-07-07 18:44

import bpp.models.cache
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    replaces = [('bpp', '0165_cache_punktacja_autora_cache_punktacja_dyscypliny'), ('bpp', '0166_auto_20190702_1200'), ('bpp', '0167_auto_20190707_2029')]

    dependencies = [
        ('bpp', '0164_auto_20190701_1303'),
    ]

    operations = [
        migrations.CreateModel(
            name='Cache_Punktacja_Autora',
            fields=[
                ('rekord_id', bpp.models.cache.TupleField(base_field=models.IntegerField(), db_index=True, size=2)),
                ('pkdaut', models.DecimalField(decimal_places=4, max_digits=20)),
                ('slot', models.DecimalField(decimal_places=4, max_digits=20)),
                ('autor', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Autor')),
                ('dyscyplina', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Dyscyplina_Naukowa')),
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.CreateModel(
            name='Cache_Punktacja_Dyscypliny',
            fields=[
                ('rekord_id', bpp.models.cache.TupleField(base_field=models.IntegerField(), db_index=True, size=2)),
                ('pkd', models.DecimalField(decimal_places=4, max_digits=20)),
                ('slot', models.DecimalField(decimal_places=4, max_digits=20)),
                ('dyscyplina', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Dyscyplina_Naukowa')),
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
    ]
