# Generated by Django 3.0.11 on 2021-04-27 19:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0262_bppuser_pbn_token"),
    ]

    operations = [
        migrations.AddField(
            model_name="uczelnia",
            name="pbn_aktualizuj_na_biezaco",
            field=models.BooleanField(
                default=False,
                help_text="Aktualizuj rekordy w PBN przy każdym zapisie rekordu",
                verbose_name="Aktualizuj PBN na bieżąco",
            ),
        ),
        migrations.AddField(
            model_name="uczelnia",
            name="pbn_integracja",
            field=models.BooleanField(
                default=False,
                help_text="Wymaga prawidłowo wypełnionych pól 'Adres API w PBN', 'Nazwa aplikacji w PBN', 'Token aplikacji w PBN' oraz łączności między serwerem BPP a serwerem PBN. ",
                verbose_name="Czy używać integracji z PBN?",
            ),
        ),
    ]
