# Generated by Django 3.0.14 on 2021-08-20 13:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0030_auto_20210818_2343"),
    ]

    operations = [
        migrations.AlterField(
            model_name="scientist",
            name="from_institution_api",
            field=models.NullBooleanField(
                db_index=True, verbose_name="Rekord z API instytucji"
            ),
        ),
    ]
