# Generated by Django 3.0.11 on 2021-02-28 12:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("import_dyscyplin", "0018_auto_20200329_1719"),
    ]

    operations = [
        migrations.AlterField(
            model_name="kolumna",
            name="rodzaj_pola",
            field=models.CharField(
                choices=[
                    ("tytuł", "tytuł"),
                    ("nazwisko", "nazwisko"),
                    ("imię", "imię"),
                    ("orcid", "orcid"),
                    ("pbn_id", "pbn_id"),
                    ("nazwa jednostki", "nazwa jednostki"),
                    ("wydział", "wydział"),
                    ("dyscyplina", "dyscyplina"),
                    ("kod dyscypliny", "kod dyscypliny"),
                    ("procent dyscypliny", "procent dyscypliny"),
                    ("subdyscyplina", "subdyscyplina"),
                    ("kod subdyscypliny", "kod subdyscypliny"),
                    ("procent subdyscypliny", "procent subdyscypliny"),
                    ("pomiń", "pomiń"),
                ],
                max_length=50,
            ),
        ),
    ]
