# Generated by Django 3.0.11 on 2021-01-30 13:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("raport_slotow", "0006_auto_20210125_2330"),
    ]

    operations = [
        migrations.AddField(
            model_name="raportslotowuczelnia",
            name="pokazuj_zerowych",
            field=models.BooleanField(
                default=False,
                help_text="Autor z zerowym slotem to autor, który ma na zadany okres czasu zadeklarowane dyscypliny,\n        ale nie posiada żadnych punktowanych prac. ",
                verbose_name="Dołączaj autorów z zerowymi slotami",
            ),
        ),
    ]
