# Generated by Django 2.2.10 on 2020-03-15 21:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0202_fix_autorzy_bez_nazwisk"),
        ("bpp", "0204_cache_punktacja_autora_query_view"),
    ]

    operations = []
