# Generated by Django 3.0.14 on 2022-04-12 21:43

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0314_punktacja_zrodla_kwarty"),
        ("import_pracownikow", "0005_auto_20210307_1204"),
    ]

    operations = [
        migrations.AddField(
            model_name="importpracownikowrow",
            name="tytul",
            field=models.ForeignKey(
                null=True, on_delete=django.db.models.deletion.SET_NULL, to="bpp.Tytul"
            ),
        ),
    ]
