# Generated by Django 2.1.7 on 2019-03-03 09:29

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0153_django21'),
    ]

    operations = [
        migrations.AlterField(
            model_name='patent_autor',
            name='autor',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Autor'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle_autor',
            name='autor',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Autor'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte_autor',
            name='autor',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Autor'),
        ),
    ]
