# Generated by Django 3.0.7 on 2020-08-03 18:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("notifications", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="notification",
            name="acknowledged",
            field=models.BooleanField(default=False),
        ),
    ]
