{% extends "base.html" %}

{% block extratitle %}
    Zmiana hasła
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li class="current">Zmiana hasła</li>
{% endblock %}

{% block content %}
    <h1>Udało się!</h1>
    Hasło zostało zmienione poprawnie. Dziękuję!
{% endblock %}