# Generated by Django 3.0.7 on 2020-07-27 12:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0214_auto_20200628_2344"),
    ]

    operations = [
        migrations.AddField(
            model_name="praca_doktorska",
            name="numer_odbitki",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="numer_odbitki",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="numer_odbitki",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="numer_odbitki",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name="charakter_formalny",
            name="charakter_ogolny",
            field=models.CharField(
                choices=[
                    ("art", "Artykuł"),
                    ("ksi", "Książka"),
                    ("roz", "Rozdział"),
                    ("xxx", "Inne"),
                ],
                default="xxx",
                help_text="Charakter ogólny uzywany jest m.in. do generowania opisów bibliograficznych. Stanowi on\n        ogólne określenie rekordu, czy jest to książka, rozdział czy coś innego. ",
                max_length=3,
            ),
        ),
    ]
