# Generated by Django 2.1.7 on 2019-07-01 11:40

import bpp.models.cache
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0164_auto_20190701_1303'),
    ]

    operations = [
        migrations.CreateModel(
            name='Cache_Punktacja_Autora',
            fields=[
                ('id', bpp.models.cache.TupleField(base_field=models.IntegerField(), primary_key=True, serialize=False, size=2)),
                ('pkdaut', models.DecimalField(decimal_places=4, max_digits=20)),
                ('slot', models.DecimalField(decimal_places=4, max_digits=20)),
                ('autor', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Autor')),
                ('dyscyplina', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Dyscyplina_Naukowa')),
            ],
        ),
        migrations.CreateModel(
            name='Cache_Punktacja_Dyscypliny',
            fields=[
                ('id', bpp.models.cache.TupleField(base_field=models.IntegerField(), primary_key=True, serialize=False, size=2)),
                ('pkd', models.DecimalField(decimal_places=4, max_digits=20)),
                ('slot', models.DecimalField(decimal_places=4, max_digits=20)),
                ('dyscyplina', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Dyscyplina_Naukowa')),
            ],
        ),
    ]
