# Generated by Django 2.1.7 on 2019-07-02 10:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0165_cache_punktacja_autora_cache_punktacja_dyscypliny'),
    ]

    operations = [
        migrations.RenameField(
            model_name='cache_punktacja_autora',
            old_name='id',
            new_name='rekord_id',
        ),
        migrations.RenameField(
            model_name='cache_punktacja_dyscypliny',
            old_name='id',
            new_name='rekord_id',
        ),
    ]
