{% extends "base.html" %}

{% block extratitle %}
    Zmiana hasła
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li class="current">Zmiana hasła</li>
{% endblock %}

{% block content %}
    <div data-alert class="alert-box warning round ">
        Jeżeli zmiana hasła odbędzie się poprawnie, zostanie wyświetlony
        formularz
        logowania. Prosimy o zalogowanie się do systemu przy użyciu nowego
        hasła.
        <a href="#" class="close">&times;</a>
    </div>    {% load crispy_forms_tags %}
    {% crispy form %}
{% endblock %}