# Generated by Django 2.1.7 on 2019-03-25 20:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0156_auto_20190319_1648'),
        ('bpp', '0157_auto_20190324_1834'),
    ]

    operations = [
    ]
