# Generated by Django 3.0.14 on 2021-08-08 23:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0022_auto_20210809_0120"),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name="scientist",
            unique_together={
                (
                    "mongoId",
                    "lastName",
                    "name",
                    "pbnId",
                    "qualifications",
                    "orcid",
                    "polonUid",
                )
            },
        ),
    ]
