{% extends "admin/change_form.html" %}

{% block object-tools-items %}
    {% if original.moze_zostac_zwrocony %}
        <li><a href="../zwroc/">Zwróć do autora</a></li>
    {% endif %}
    {{ block.super }}
{% endblock %}
