# Generated by Django 3.2.15 on 2022-08-16 10:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("zglos_publikacje", "0007_auto_20220816_1019"),
    ]

    operations = [
        migrations.AddField(
            model_name="zgloszenie_publikacji",
            name="ostatnio_zmieniony",
            field=models.DateTimeField(auto_now=True, db_index=True, null=True),
        ),
        migrations.AddField(
            model_name="zgloszenie_publikacji",
            name="przyczyna_zwrotu",
            field=models.TextField(blank=True, null=True),
        ),
    ]
