# Generated by Django 3.0.14 on 2021-08-13 23:04

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0285_auto_20210814_0103"),
    ]

    operations = [
        migrations.AlterField(
            model_name="praca_doktorska",
            name="jezyk_orig",
            field=models.ForeignKey(
                blank=True,
                help_text="Dla tłumaczeń. Wartość eksportowana do PBN. ",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="bpp.Jezyk",
                verbose_name="Język oryginalny",
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="jezyk_orig",
            field=models.ForeignKey(
                blank=True,
                help_text="Dla tłumaczeń. Wartość eksportowana do PBN. ",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="bpp.Jezyk",
                verbose_name="Język oryginalny",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="jezyk_orig",
            field=models.ForeignKey(
                blank=True,
                help_text="Dla tłumaczeń. Wartość eksportowana do PBN. ",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="bpp.Jezyk",
                verbose_name="Język oryginalny",
            ),
        ),
    ]
