<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Przekroczono dozwolony czas wykonywania zapytania</title>
</head>
<body>
<div style="width:40%; text-align:left; margin: 0 auto">
    <p>&nbsp;</p>
    <p>&nbsp;</p>
    <h1>
        <img src="/static/bpp/svg/database.svg" style="max-width: 2.8em;"
             align="absmiddle"/>
        Przekroczono dozwolony czas wykonywania zapytania
    </h1>
    Zapytanie, które wysłałeś/aś do serwera wykonywało się zbyt długo.
    <p>
        Ten błąd <b>może być tymczasowy</b> czyli może być związany z
        nadmiernym chwilowym obciążeniem naszego serwera, więc wykonanie tego
        zapytania jeszcze raz po krótkiej chwili (odświeżenie strony WWW) może
        pomóc.
    </p>
    <p>
        Jeżeli jednak otrzymujesz ten komunikat zawsze, gdy chcesz wywołać
        daną funkcję, skontaktuj się z administratorem systemu. Możliwe jest,
        iż zapytanie,
        które próbujesz wykonać, ma na tyle skomplikowane parametry, że
        powoduje nadmierne
        obciążenie serwera i w rezultacie albo oprogramowanie musi być
        zoptymalizowane, albo też Twoje zapytanie musi być wykonane w inny
        sposób.
    </p>
    Ten błąd <b>nie jest</b> zgłaszany automatycznie do administratora systemu.
</div>
</body>
</html>