<fieldset>
    <legend>... opracowane w latach:</legend>
    <div class="row row-collapse">
        {% for rok in prace_w_latach reversed %}
            <div class="large-1 small-3 columns">
                <input type="checkbox" name="rok"
                       id="rok_{{ rok }}" value="{{ rok }}"/>
                <label for="rok_{{ rok }}">

                    {{ rok }}</label>
            </div>
        {% endfor %}
        <span class="filler"></span>
    </div>
</fieldset>