# -*- encoding: utf-8 -*-

from django.test import TestCase

# Create your tests here.


class TestCreateTestDb(TestCase):
    def test_create_test_db(self):
        """Pusty testcase - jego uruchomienie zawsze kończy się powodzeniem
        """

        return True
