# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-03-05 13:44
from __future__ import unicode_literals

from django.db import migrations
from bpp.migration_util import load_custom_sql

class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0120_kc_if_3_cyfry'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0121_rekord_ostatnio_zmieniony_dla")
        ),
    ]
