# Generated by Django 3.0.14 on 2021-06-13 22:59

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0277_lepsze_global_search"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0278_autorzy_profil_orcid")
        ),
        # To musi być wczytane, bo "DROP CASCADE" i gubi widoki ewaluacyjne
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0207_uczelnia_analiza_view")
        ),
    ]
