/*! Select2 4.1.0-rc.0 | https://github.com/select2/select2/blob/master/LICENSE.md */
var dalLoadLanguage=function(n){var e;(e=n&&n.fn&&n.fn.select2&&n.fn.select2.amd?n.fn.select2.amd:e).define("select2/i18n/sr-Cyrl",[],function(){function e(n,e,t,u){return n%10==1&&n%100!=11?e:2<=n%10&&n%10<=4&&(n%100<12||14<n%100)?t:u}return{errorLoading:function(){return"Преузимање није успело."},inputTooLong:function(n){n=n.input.length-n.maximum;return"Обришите "+n+" симбол"+e(n,"","а","а")},inputTooShort:function(n){n=n.minimum-n.input.length;return"Укуцајте бар још "+n+" симбол"+e(n,"","а","а")},loadingMore:function(){return"Преузимање још резултата…"},maximumSelected:function(n){return"Можете изабрати само "+n.maximum+" ставк"+e(n.maximum,"у","е","и")},noResults:function(){return"Ништа није пронађено"},searching:function(){return"Претрага…"},removeAllItems:function(){return"Уклоните све ставке"}}}),e.define,e.require},event=new CustomEvent("dal-language-loaded",{lang:"sr-Cyrl"});document.dispatchEvent(event);