# Generated by Django 3.0.14 on 2021-10-26 09:37

import django.db.models.deletion
from django.db import migrations, models

import ewaluacja2021.fields


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0306_delete_ewaluacja2021liczbandlauczelni"),
        ("ewaluacja2021", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="IloscUdzialowDlaAutora",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "ilosc_udzialow",
                    ewaluacja2021.fields.LiczbaNField(decimal_places=4, max_digits=9),
                ),
                (
                    "ilosc_udzialow_monografie",
                    ewaluacja2021.fields.LiczbaNField(decimal_places=4, max_digits=9),
                ),
                (
                    "autor",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="bpp.Autor"
                    ),
                ),
                (
                    "dyscyplina_naukowa",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="bpp.Dyscyplina_Naukowa",
                    ),
                ),
            ],
            options={
                "verbose_name": "ilość udziałów dla autora",
                "verbose_name_plural": "ilości udziałów dla autorów",
                "unique_together": {("autor", "dyscyplina_naukowa")},
            },
        ),
        migrations.DeleteModel(
            name="LiczbaNDlaAutora",
        ),
    ]
