LATA_2019_2021 = 0
LATA_2017_2018 = 1

DEC2INT = 10000

# Zakres lat dla wyszukiwania prac do raportów "ewaluacja 2021"
ROK_MIN = 2017
ROK_MAX = 2021


IMPORT_MAKSYMALNYCH_SLOTOW_COLUMNS = [
    "Stopień / Tytuł",
    "Nazwisko",
    "Imię",
    "ORCID",
    "Dyscyplina",
    "Uwzględniony w ewaluacji",
    "maksymalna suma udziałów jednostkowych - wszystkie dyscypliny",
    "maksymalna suma udziałów jednostkowych - monografie",
]
