# Generated by Django 2.1.7 on 2019-08-31 23:18

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ('rozbieznosci_dyscyplin', '0001_widok_rozbieznosci'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0002_rok_2017_i_wyzej", app_name="rozbieznosci_dyscyplin")
        ),
    ]
