# Generated by Django 3.2.15 on 2022-08-17 22:12

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0325_nullbooleanfield"),
    ]

    operations = [
        migrations.AddField(
            model_name="uczelnia",
            name="wymagaj_informacji_o_oplatach",
            field=models.BooleanField(
                default=True,
                help_text="Gdy zaznaczone, moduł 'Zgłaszanie publikacji' będzie wyświetlać użytkownikowi formularz "
                "informacji o opłatach za publikację w przypadku zgłaszania artykułu lub monografii. Gdy "
                "odznaczone, taki formularz nie bedzie wyświetlany, niezależnie od rodzaju zgłaszanej "
                "publikacji. ",
                verbose_name="Wymagaj inforamcji o opłatach",
            ),
        ),
        migrations.AlterField(
            model_name="patent",
            name="rok",
            field=models.IntegerField(
                db_index=True,
                help_text="Rok uwzględniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)",
                validators=[django.core.validators.MinValueValidator(0)],
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota brutto (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="rok",
            field=models.IntegerField(
                db_index=True,
                help_text="Rok uwzględniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)",
                validators=[django.core.validators.MinValueValidator(0)],
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota brutto (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="rok",
            field=models.IntegerField(
                db_index=True,
                help_text="Rok uwzględniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)",
                validators=[django.core.validators.MinValueValidator(0)],
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota brutto (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="rok",
            field=models.IntegerField(
                db_index=True,
                help_text="Rok uwzględniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)",
                validators=[django.core.validators.MinValueValidator(0)],
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota brutto (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="rok",
            field=models.IntegerField(
                db_index=True,
                help_text="Rok uwzględniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)",
                validators=[django.core.validators.MinValueValidator(0)],
            ),
        ),
    ]
