# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-16 11:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0126_zewnetrzna_baza_danych'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='wydawnictwo_ciagle_zewnetrzna_baza_danych',
            options={'verbose_name': 'powiązanie wydawnictwa ciągłego z zewnętrznymi bazami danych', 'verbose_name_plural': 'powiązania wydawnictw ciągłych z zewnętrznymi bazami danych'},
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle_zewnetrzna_baza_danych',
            name='info',
            field=models.CharField(blank=True, max_length=512, null=True, verbose_name='Informacje dodatkowe'),
        ),
    ]
