{% extends "base.html" %}
{% load humanize static %}

{% block extratitle %}
    Import dyscyplin naukowych
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li class="current">import dyscyplin</li>
{% endblock %}


{% block content %}
    <h2>Import dyscyplin
        <a class="button success" id="add-new-file" href="./create">
            <i class="fi-page-add"></i>
            dodaj nowy plik
        </a>
        <a class="button secondary" id="download-example-file" href="{% static "import_dyscyplin/xlsx/default.xlsx" %}">
            <i class="fi-page-edit"></i>
            pobierz plik wzorcowy
        </a>
    </h2>
    {% if object_list.exists %}
        <p>
            Poniżej znajduje się lista plików zaimportowanych przez Ciebie do systemu wraz z
            ich obecnym stanem oraz datą ostatnich zmian.
        </p>
        <ul>
            {% for object in object_list %}
                <li>
                    <a href="{% url "import_dyscyplin:detail" object.pk %}">
                        plik <strong>{{ object.plik.name }}</strong>
                        {% if object.plik.exists %}
                        {{ object.plik.size|filesizeformat }}
                        {% endif %}
                        zmodyfikowany {{ object.modified }}
                    </a> - stan analizy:
                    <strong>{{ object.stan }}</strong>
                </li>
            {% endfor %}
        </ul>
    {% else %}
        Brak informacji o importowanych plikach z danymi dyscyplin w systemie.
    {% endif %}

{% endblock %}
