# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-09 09:29
from __future__ import unicode_literals

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion
import django_fsm


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0121_rekord_ostatnio_zmieniony_dla'),
        ('import_dyscyplin', '0002_import_dyscyplin_web_page_uid'),
    ]

    operations = [
        migrations.CreateModel(
            name='Import_Dyscyplin_Row',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('row_no', models.IntegerField()),
                ('original', django.contrib.postgres.fields.jsonb.JSONField()),
                ('autor_id', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bpp.Autor')),
                ('jednostka_id', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bpp.Jednostka')),
            ],
        ),
        migrations.AlterField(
            model_name='import_dyscyplin',
            name='stan',
            field=django_fsm.FSMField(choices=[('nowy', 'nowy'), ('przeanalizowany', 'przeanalizowany'), ('błędny', 'błędny'), ('zintegrowany', 'zintegrowany')], default='nowy', max_length=50, protected=True),
        ),
        migrations.AddField(
            model_name='import_dyscyplin_row',
            name='parent',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='import_dyscyplin.Import_Dyscyplin'),
        ),
        migrations.AddField(
            model_name='import_dyscyplin_row',
            name='wydzial_id',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bpp.Wydzial'),
        ),
    ]
