.multiseek-fieldset{box-shadow:8px 8px 8px rgba(200,200,200,0.3);border:1px solid #eeeeee;background:rgba(200,200,200,0.2);padding-top:10px}.multiseek-remove-from-results{display:none;color:red;text-weight:bold}.multiseek-remove-from-results a{color:red}.multiseek-row:hover .multiseek-remove-from-results{display:inline}