# Generated by Django 2.1.7 on 2019-03-24 18:06

from django.db import migrations, models
import django_fsm


class Migration(migrations.Migration):

    dependencies = [
        ('import_dyscyplin', '0013_auto_20190324_1826'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='kolumna',
            options={'ordering': ['kolejnosc']},
        ),
        migrations.AddField(
            model_name='import_dyscyplin',
            name='wiersz_naglowka',
            field=models.PositiveSmallIntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='kolumna',
            name='kolejnosc',
            field=models.PositiveSmallIntegerField(default=0),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='import_dyscyplin',
            name='stan',
            field=django_fsm.FSMField(choices=[('nowy', 'nowy'), ('określanie opcji importu', 'określanie opcji importu'), ('przeanalizowany', 'przeanalizowany'), ('błędny', 'błędny'), ('zintegrowany', 'zintegrowany')], default='nowy', max_length=50, protected=True),
        ),
    ]
