/*! Select2 4.1.0-rc.0 | https://github.com/select2/select2/blob/master/LICENSE.md */
var dalLoadLanguage=function(e){var n;(n=e&&e.fn&&e.fn.select2&&e.fn.select2.amd?e.fn.select2.amd:n).define("select2/i18n/ca",[],function(){return{errorLoading:function(){return"La càrrega ha fallat"},inputTooLong:function(e){e=e.input.length-e.maximum;return"Si us plau, elimina "+e+" car"+(1==e?"àcter":"àcters")},inputTooShort:function(e){e=e.minimum-e.input.length;return"Si us plau, introdueix "+e+" car"+(1==e?"àcter":"àcters")},loadingMore:function(){return"Carregant més resultats…"},maximumSelected:function(e){var n="Només es pot seleccionar "+e.maximum+" element";return 1!=e.maximum&&(n+="s"),n},noResults:function(){return"No s'han trobat resultats"},searching:function(){return"Cercant…"},removeAllItems:function(){return"Treu tots els elements"}}}),n.define,n.require},event=new CustomEvent("dal-language-loaded",{lang:"ca"});document.dispatchEvent(event);