# Generated by Django 3.0.14 on 2022-07-06 21:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0322_oplaty_za_publikacje"),
    ]

    operations = [
        migrations.AddField(
            model_name="jednostka",
            name="pokazuj_opis",
            field=models.BooleanField(
                default=True,
                help_text="Gdy to pole jest zaznaczone, system wyświetli pole 'Opis' na podstronie jednostki.",
            ),
        ),
    ]
