# Generated by Django 3.0.11 on 2021-03-23 00:06

import datetime

from django.db import migrations, models

from django.utils.timezone import utc


class Migration(migrations.Migration):

    dependencies = [
        ("rozbieznosci_if", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="ignorujrozbieznoscif",
            options={"verbose_name": "ignorowanie rozbieżności IF"},
        ),
        migrations.AddField(
            model_name="ignorujrozbieznoscif",
            name="created_on",
            field=models.DateTimeField(
                auto_created=True,
                default=datetime.datetime(2021, 3, 23, 0, 6, 43, 174113, tzinfo=utc),
            ),
            preserve_default=False,
        ),
    ]
