# Generated by Django 2.1.7 on 2019-07-18 20:44

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0167_dyscyplina_change_trigger_fix'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0168_dyscyplina_w_autorzy_mat")
        ),

    ]
