{% extends "base.html" %}

{% load columns %}

{% block extratitle %}
    Indeks autorów{% if wybrana != None %} - litera {{ wybrana }}{% endif %}
{% endblock %}


{% block breadcrumbs %}
    {{ block.super }}
    <li {% if wybrana == None %}class="current"{% endif %}>
        {% if wybrana != None %}
            <a href="{% url "bpp:browse_autorzy" %}">
        {% endif %}Autorzy
        {% if wybrana != None %}
            </a>
        {% endif %}
    </li>

    {% if wybrana != None %}
        <li class="current">litera {{ wybrana }}</li>
    {% endif %}

{% endblock %}

{% block content %}
    {% url "bpp:browse_autorzy" as browse_autorzy %}
    {% include "browse/literki.html" with pierwszy_tab="wszyscy" url=browse_autorzy %}
    {% include "browse/go_to_admin_list.html" with url="admin:bpp_autor_changelist" group="wprowadzanie danych" text="<i class='fi-wrench'></i> wyświetl w module redagowania" %}

    {% url "bpp:browse_autorzy" as browse_autorzy %}

    <div class="grid-x hide-for-print">
        <div class="large-4 medium-4 small-12 columns">
            {% include "browse/search_form.html" with url=browse_autorzy tekst="Wpisz początek nazwiska i wciśnij ENTER..." name="search" flt=flt %}
        </div>
        <div class="large-8 medium-8 small-12 columns" style="text-align: right;">
            {% include "pagination.html" %}
        </div>
    </div>





    <div class="grid-x grid-margin-x">
        {% for col in object_list|columns:4 %}
            <div class="large-3 cell">
                <ul class="no-bullet">
                    {% for item in col %}
                        <li>
                            <a href="{% url "bpp:browse_autor" item.slug %}">
                                {{ item.get_full_name_surname_first }}
                            </a>

                        </li>


                    {% endfor %}</ul>
            </div>
        {% endfor %}
        {% if not object_list %}
            <div class="callout warning cell">
                Nie znaleziono takich autorów. <p></p>
                <a href="{% url "bpp:browse_autorzy" %}">Kliknij tutaj, aby spróbować ponownie.</a>
            </div>

        {% endif %}
    </div><!-- /row -->



{% endblock %}