{% load i18n %}

<div id="CookielawBanner"
     class="sticky hide-for-print" data-sticky data-stick-to="bottom">
    <div class="callout warning">
        <strong>{% trans "COOKIE_INFO_HEADER" %}</strong>: {% trans "COOKIE_INFO_PARA" %}
        <a class="btn btn-primary pull-right"
           href="javascript:Cookielaw.createCookielawCookie();">
            <b>{% trans "COOKIE_INFO_OK" %}</b></a>
        </p>
    </div>
</div>
