{% extends "bare.html" %}

{% load compress %}
{% load static %}
{% load static %}

{% block extratitle %}
    Rezultat wyszukiwania
{% endblock %}
{% block body %}
    {% include "print-title.html" %}
    {% include "multiseek/common-results.html" with paging=5 live="1" %}
{% endblock %}
