<fieldset>
    <legend>... tytułując:</legend>
    <div class="row row-collapse">
        <div class="small-10 large-10" style="margin-left: 10px;">
            <input type="text" name="suggested-title" value="{{ obj }}" />
            Tytuł wyszukiwania możesz zmienić, klikając go dwukrotnie.
        </div>
    </div>
</fieldset>