# Generated by Django 2.1.10 on 2019-10-27 20:58

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0188_auto_20191027_1737'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='seria_wydawnicza',
            options={'ordering': ('nazwa',), 'verbose_name': 'seria wydawnicza', 'verbose_name_plural': 'serie wydawnicze'},
        ),
    ]
