# Generated by Django 3.2.14 on 2022-07-07 22:32

import django.core.serializers.json
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("import_pracownikow", "0006_importpracownikowrow_tytul"),
    ]

    operations = [
        migrations.AlterField(
            model_name="importpracownikowrow",
            name="dane_z_xls",
            field=models.JSONField(
                blank=True,
                encoder=django.core.serializers.json.DjangoJSONEncoder,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="importpracownikowrow",
            name="dane_znormalizowane",
            field=models.JSONField(
                blank=True,
                encoder=django.core.serializers.json.DjangoJSONEncoder,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="importpracownikowrow",
            name="log_zmian",
            field=models.JSONField(
                blank=True,
                encoder=django.core.serializers.json.DjangoJSONEncoder,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="importpracownikowrow",
            name="podstawowe_miejsce_pracy",
            field=models.BooleanField(null=True),
        ),
    ]
