# Generated by Django 3.0.11 on 2021-02-28 16:39

import django.contrib.postgres.fields.jsonb
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0240_auto_20210228_1739"),
        ("import_pracownikow", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="ImportPracownikowRow",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("wiersz_xls", models.PositiveSmallIntegerField()),
                (
                    "dane_z_xls",
                    django.contrib.postgres.fields.jsonb.JSONField(
                        blank=True, null=True
                    ),
                ),
                (
                    "autor",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="bpp.Autor"
                    ),
                ),
                (
                    "autor_jednostka",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="bpp.Autor_Jednostka",
                    ),
                ),
                (
                    "jednostka",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE, to="bpp.Jednostka"
                    ),
                ),
                (
                    "parent",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="import_pracownikow.ImportPracownikow",
                    ),
                ),
            ],
        ),
    ]
