# Generated by Django 3.0.4 on 2020-03-29 15:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0207_uczelnia_analiza_view"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="cache_punktacja_autora_query_view",
            options={
                "managed": False,
                "ordering": ("rekord__tytul_oryginalny", "dyscyplina__nazwa"),
            },
        ),
        migrations.AlterField(
            model_name="charakter_formalny",
            name="level",
            field=models.PositiveIntegerField(editable=False),
        ),
        migrations.AlterField(
            model_name="charakter_formalny",
            name="lft",
            field=models.PositiveIntegerField(editable=False),
        ),
        migrations.AlterField(
            model_name="charakter_formalny",
            name="rght",
            field=models.PositiveIntegerField(editable=False),
        ),
    ]
