# -*- coding: utf-8 -*-
# Generated by Django 1.11.8 on 2018-01-01 19:17
from __future__ import unicode_literals

from django.db import migrations
import model_utils.fields


class Migration(migrations.Migration):

    dependencies = [
        ('miniblog', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='article',
            name='article_body',
            field=model_utils.fields.SplitField(help_text='Użyj znacznika podziału „&lt;!-- tutaj --&gt;” w przypadku jeżeli chcesz wyświetlić krótszą wersję treści artykułu', no_excerpt_field=True, verbose_name='Article body'),
        ),
    ]
