# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-17 10:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0084_strona_tom_nr_zeszytu'),
    ]

    operations = [
        migrations.AlterField(
            model_name='patent',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ', max_length=50, null=True),
        ),
    ]
