# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-06-07 10:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0133_liczba_autorow'),
    ]

    operations = [
        migrations.AddField(
            model_name='uczelnia',
            name='domyslnie_afiliuje',
            field=models.BooleanField(default=True, help_text='Przy powiązaniach autor + wydawnictwo, zaznaczaj domyślnie,\n        że autor afiliuje do jednostki, która jest wpisywana.', verbose_name='Domyślnie zaznaczaj, że autor afiliuje'),
        ),
    ]
