# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-11-10 23:35
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0112_fix_refresh_cache'),
    ]

    operations = [
        migrations.AlterField(
            model_name='patent_autor',
            name='rekord',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='autorzy_set', to='bpp.Patent'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle_autor',
            name='rekord',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='autorzy_set', to='bpp.Wydawnictwo_Ciagle'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte_autor',
            name='rekord',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='autorzy_set', to='bpp.Wydawnictwo_Zwarte'),
        ),
    ]
