# Generated by Django 3.2.14 on 2022-07-07 22:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("formdefaults", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="formfielddefaultvalue",
            name="value",
            field=models.JSONField(blank=True, null=True, verbose_name="Wartość"),
        ),
    ]
