# Generated by Django 3.0.11 on 2021-03-08 11:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0244_auto_20210307_2329"),
    ]

    operations = [
        migrations.AlterField(
            model_name="typ_kbn",
            name="charakter_pbn",
            field=models.ForeignKey(
                blank=True,
                default=None,
                help_text="Wartość wybrana w tym polu zostanie użyta jako\n        fallback, tzn. jeżeli dla charakteru formalnego danego rekordu nie\n        określono odpowiedniego charakteru PBN, to zostanie użyta wartość\n        tego pola, o ile wybrana. ",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="bpp.Charakter_PBN",
                verbose_name="Charakter PBN",
            ),
        ),
        migrations.AlterField(
            model_name="typ_odpowiedzialnosci",
            name="typ_ogolny",
            field=models.SmallIntegerField(
                choices=[
                    (0, "autor"),
                    (1, "redaktor"),
                    (2, "inny"),
                    (3, "tłumacz"),
                    (4, "komentator"),
                    (5, "recenzent"),
                    (6, "opracował"),
                ],
                db_index=True,
                default=0,
                help_text="Pole to jest używane celem rozróżniania typu odpowiedzialności\n        na cele eksportu do PBN (autor i redaktor) oraz może być też wykorzystywane\n        np. w raportach autorów i jednostek.\n        ",
                verbose_name="Ogólny typ odpowiedzialności",
            ),
        ),
    ]
