# Generated by Django 3.0.7 on 2020-06-28 21:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0213_merge_20200607_2047"),
    ]

    operations = [
        migrations.AddField(
            model_name="patent",
            name="nie_eksportuj_przez_api",
            field=models.BooleanField(
                db_index=True,
                default=False,
                help_text="Jeżeli zaznaczone, to ten rekord nie będzie dostępny przez JSON REST API",
                verbose_name="Nie eksportuj przez API",
            ),
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="nie_eksportuj_przez_api",
            field=models.BooleanField(
                db_index=True,
                default=False,
                help_text="Jeżeli zaznaczone, to ten rekord nie będzie dostępny przez JSON REST API",
                verbose_name="Nie eksportuj przez API",
            ),
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="nie_eksportuj_przez_api",
            field=models.BooleanField(
                db_index=True,
                default=False,
                help_text="Jeżeli zaznaczone, to ten rekord nie będzie dostępny przez JSON REST API",
                verbose_name="Nie eksportuj przez API",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="nie_eksportuj_przez_api",
            field=models.BooleanField(
                db_index=True,
                default=False,
                help_text="Jeżeli zaznaczone, to ten rekord nie będzie dostępny przez JSON REST API",
                verbose_name="Nie eksportuj przez API",
            ),
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="nie_eksportuj_przez_api",
            field=models.BooleanField(
                db_index=True,
                default=False,
                help_text="Jeżeli zaznaczone, to ten rekord nie będzie dostępny przez JSON REST API",
                verbose_name="Nie eksportuj przez API",
            ),
        ),
    ]
