# Generated by Django 3.0.11 on 2021-01-01 16:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0231_ukryj_status_korekty"),
    ]

    operations = [
        migrations.AlterField(
            model_name="autor",
            name="pseudonim",
            field=models.CharField(
                blank=True,
                help_text="\n    Jeżeli w bazie danych znajdują się autorzy o zbliżonych imionach, nazwiskach i tytułach naukowych,\n    skorzystaj z tego pola aby ułatwić ich rozróżnienie. Pseudonim pokaże się w polach wyszukiwania\n    oraz na podstronie autora, po nazwisku i tytule naukowym.",
                max_length=300,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="sortuj_jednostki_alfabetycznie",
            field=models.BooleanField(
                default=True,
                help_text="Jeżeli ustawione na 'FAŁSZ', sortowanie jednostek będzie odbywało się ręcznie\n        tzn za pomocą ustalonej przez administratora systemu kolejności. ",
            ),
        ),
    ]
