# Generated by Django 3.0.11 on 2020-12-25 23:59

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0228_merge_20201225_1931"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0229_nowe_sumy_status_korekty")
        )
    ]
