# Generated by Django 2.2.10 on 2020-02-29 15:44

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0197_auto_20200223_2142"),
    ]

    operations = [
        migrations.AddField(
            model_name="wydawca",
            name="alias_dla",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="bpp.Wydawca",
            ),
        ),
        migrations.AlterField(
            model_name="patent",
            name="strony",
            field=models.CharField(
                blank=True,
                help_text='Jeżeli uzupełnione, to pole będzie eksportowane do\n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z\n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć\n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola\n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana\n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie\n        tego pola na podstawie pola "Szczegóły".\n        ',
                max_length=250,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="patent",
            name="tom",
            field=models.CharField(
                blank=True,
                help_text="Jeżeli uzupełnione, to pole będzie eksportowane do\n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z\n        pola 'Informacje'. Kliknięcie przycisku \"Uzupełnij\" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ",
                max_length=50,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="patent_autor",
            name="afiliuje",
            field=models.BooleanField(
                default=True,
                help_text="Afiliuje\n    się do jednostki podanej w przypisaniu",
            ),
        ),
        migrations.AlterField(
            model_name="patent_autor",
            name="zatrudniony",
            field=models.BooleanField(
                default=False,
                help_text="Pracownik\n    jednostki podanej w przypisaniu",
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="liczba_cytowan",
            field=models.PositiveIntegerField(
                blank=True,
                help_text="Wartość aktualizowana jest automatycznie raz na kilka dni w przypadku\n        skonfigurowania dostępu do API WOS AMR (przez obiekt 'Uczelnia'). Możesz również\n        czaktualizować tą wartość ręcznie, naciskając przycisk. ",
                null=True,
                verbose_name="Liczba cytowań",
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="strony",
            field=models.CharField(
                blank=True,
                help_text='Jeżeli uzupełnione, to pole będzie eksportowane do\n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z\n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć\n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola\n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana\n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie\n        tego pola na podstawie pola "Szczegóły".\n        ',
                max_length=250,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="tom",
            field=models.CharField(
                blank=True,
                help_text="Jeżeli uzupełnione, to pole będzie eksportowane do\n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z\n        pola 'Informacje'. Kliknięcie przycisku \"Uzupełnij\" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ",
                max_length=50,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="liczba_cytowan",
            field=models.PositiveIntegerField(
                blank=True,
                help_text="Wartość aktualizowana jest automatycznie raz na kilka dni w przypadku\n        skonfigurowania dostępu do API WOS AMR (przez obiekt 'Uczelnia'). Możesz również\n        czaktualizować tą wartość ręcznie, naciskając przycisk. ",
                null=True,
                verbose_name="Liczba cytowań",
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="strony",
            field=models.CharField(
                blank=True,
                help_text='Jeżeli uzupełnione, to pole będzie eksportowane do\n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z\n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć\n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola\n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana\n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie\n        tego pola na podstawie pola "Szczegóły".\n        ',
                max_length=250,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="tom",
            field=models.CharField(
                blank=True,
                help_text="Jeżeli uzupełnione, to pole będzie eksportowane do\n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z\n        pola 'Informacje'. Kliknięcie przycisku \"Uzupełnij\" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ",
                max_length=50,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="liczba_cytowan",
            field=models.PositiveIntegerField(
                blank=True,
                help_text="Wartość aktualizowana jest automatycznie raz na kilka dni w przypadku\n        skonfigurowania dostępu do API WOS AMR (przez obiekt 'Uczelnia'). Możesz również\n        czaktualizować tą wartość ręcznie, naciskając przycisk. ",
                null=True,
                verbose_name="Liczba cytowań",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="nr_zeszytu",
            field=models.CharField(
                blank=True,
                help_text="Jeżeli uzupełnione, to pole będzie eksportowane do\n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z\n        pola 'Informacje'. Kliknięcie przycisku \"Uzupełnij\" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ",
                max_length=50,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="strony",
            field=models.CharField(
                blank=True,
                help_text='Jeżeli uzupełnione, to pole będzie eksportowane do\n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z\n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć\n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola\n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana\n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie\n        tego pola na podstawie pola "Szczegóły".\n        ',
                max_length=250,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="tom",
            field=models.CharField(
                blank=True,
                help_text="Jeżeli uzupełnione, to pole będzie eksportowane do\n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z\n        pola 'Informacje'. Kliknięcie przycisku \"Uzupełnij\" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ",
                max_length=50,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle_autor",
            name="afiliuje",
            field=models.BooleanField(
                default=True,
                help_text="Afiliuje\n    się do jednostki podanej w przypisaniu",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle_autor",
            name="zatrudniony",
            field=models.BooleanField(
                default=False,
                help_text="Pracownik\n    jednostki podanej w przypisaniu",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="liczba_cytowan",
            field=models.PositiveIntegerField(
                blank=True,
                help_text="Wartość aktualizowana jest automatycznie raz na kilka dni w przypadku\n        skonfigurowania dostępu do API WOS AMR (przez obiekt 'Uczelnia'). Możesz również\n        czaktualizować tą wartość ręcznie, naciskając przycisk. ",
                null=True,
                verbose_name="Liczba cytowań",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="strony",
            field=models.CharField(
                blank=True,
                help_text='Jeżeli uzupełnione, to pole będzie eksportowane do\n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z\n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć\n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola\n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana\n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie\n        tego pola na podstawie pola "Szczegóły".\n        ',
                max_length=250,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="tom",
            field=models.CharField(
                blank=True,
                help_text="Jeżeli uzupełnione, to pole będzie eksportowane do\n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z\n        pola 'Informacje'. Kliknięcie przycisku \"Uzupełnij\" powoduje\n        również automatyczne wypełnienie tego pola, o ile do formularza\n        zostały wprowadzone odpowiednie informacje. ",
                max_length=50,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte_autor",
            name="afiliuje",
            field=models.BooleanField(
                default=True,
                help_text="Afiliuje\n    się do jednostki podanej w przypisaniu",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte_autor",
            name="zatrudniony",
            field=models.BooleanField(
                default=False,
                help_text="Pracownik\n    jednostki podanej w przypisaniu",
            ),
        ),
    ]
