{% extends "base.html" %}
{% load columns %}

{% block extratitle %}
    {{ jednostka }}
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li>
        <a href="{% url "bpp:browse_wydzial" jednostka.wydzial.slug %}">{{ jednostka.wydzial }}</a>
    </li>
    <li class="current">{{ jednostka }}</li>
{% endblock %}

{% block content %}
    <h1>{{ jednostka }}</h1>
    {% include "browse/go_to_admin_change.html" with url="admin:bpp_jednostka_change" pk=jednostka.pk group="struktura" %}

    {#    <h2><a href="{% url "bpp:browse_wydzial" jednostka.wydzial.slug %}">#}
    {#    {{ jednostka.wydzial }}</a></h2>#}

    {% if jednostka.kierownik %}
        Kierownik: {{ jednostka.kierownik }}
    {% endif %}
    </a>

    {% if jednostka.parent %}
        Wchodzi w skład:
        <ul>
              <li><a href="{% url "bpp:browse_jednostka" jednostka.parent.slug %}">{{ jednostka.parent }}</a></li>
        </ul>
    {% endif %}

    {% if jednostka.children.exists %}
        Jest nadrzędną jednostką dla:<ul>
        {% for child in jednostka.children.all %}
            <li><a href="{% url "bpp:browse_jednostka" child.slug %}">{{ child }}</a></li>
        {% endfor %}
        </ul>
    {% endif %}

    {% if jednostka.pokazuj_opis and jednostka.opis %}
        {{ jednostka.opis|safe }}
    {% endif %}

    <form method="post"
          action="{% url "bpp:browse_build_search" %}"
          class="browserForm">
        {% csrf_token %}
        <input type="hidden" name="jednostka" value="{{ jednostka.pk }}"/>
        <input type="hidden" name="suggested-title" value="{{ jednostka }}"/>
        <fieldset>
            <legend>Wyszukaj dla tej jednostki:</legend>
            {% include "browse/typy.html" %}
        </fieldset>

    {% if jednostka.pracownicy.exists and jednostka.pracownicy.count < MAX_NO_AUTHORS_ON_BROWSE_JEDNOSTKA_PAGE %}
            <fieldset>
                <legend>... napisane przez obecnych pracowników:</legend>

            <div class="row">
                {% for col in jednostka.pracownicy|columns:2 %}
                    <div class="large-6 medium-12 small-12 columns"  style="white-spacE:nowrap;">
                        {% for autor in col %}
                            <input type="checkbox" name="autor"
                                       value="{{ autor.pk }}"
                                       id="autor_{{ autor.pk }}"
                                       />
                            <label for="autor_{{ autor.pk }}">
                                    <span class="custom checkbox"></span>
                                    {{ autor }}
                                    <a href="{% url "bpp:browse_autor" autor.slug %}">►</a>
                            </label><br/>
                        {% endfor %}
                    </div>
                {% endfor %}
            </div>

            </fieldset>

        {% if jednostka.wspolpracowali.exists and jednostka.wspolpracowali.count < MAX_NO_AUTHORS_ON_BROWSE_JEDNOSTKA_PAGE %}
<ul class="accordion" data-accordion data-allow-all-closed="true">
    <li class="accordion-item " data-accordion-item>
        <a href="#" class="accordion-title">... oraz osoby wcześniej związane z jednostką (kliknij aby rozwinąć listę)</a>
        <div class="accordion-content" data-tab-content>
            <fieldset>
                <div class="row">
                    {% for col in jednostka.wspolpracowali|columns:2 %}
                        <div class="large-6 medium-12 small-12 columns" style="white-spacE:nowrap;">
                            {% for autor in col %}
                                <input type="checkbox" name="autor"
                                       value="{{ autor.pk }}"
                                       id="autor_{{ autor.pk }}"
                                />
                                <label for="autor_{{ autor.pk }}">
                                    <span class="custom checkbox"></span>
                                    {{ autor }}
                                    <a href="{% url "bpp:browse_autor" autor.slug %}">►</a>
                                </label><br/>
                            {% endfor %}
                        </div>
                    {% endfor %}
                </div>

            </fieldset>
        </div>
    </li>
</ul>
        {% endif %}
    {% else %}

        {% if jednostka.autorzy_na_strone_jednostki.exists and jednostka.autorzy_na_strone_jednostki.count < MAX_NO_AUTHORS_ON_BROWSE_JEDNOSTKA_PAGE %}

            <fieldset>
                <legend>... napisane przez:</legend>

            <div class="row">
                {% for col in jednostka.autorzy_na_strone_jednostki|columns:2 %}
                    <div class="large-6 medium-12 small-12 columns"  style="white-spacE:nowrap;">
                        {% for autor in col %}
                            <input type="checkbox" name="autor"
                                       value="{{ autor.pk }}"
                                       id="autor_{{ autor.pk }}"
                                       />
                            <label for="autor_{{ autor.pk }}">
                                    <span class="custom checkbox"></span>
                                    {{ autor }}
                                    <a href="{% url "bpp:browse_autor" autor.slug %}">►</a>
                            </label><br/>
                        {% endfor %}
                    </div>
                {% endfor %}
            </div>

            </fieldset>
        {% endif %}

    {% endif %}

        {% include "browse/w_latach.html" with prace_w_latach=jednostka.prace_w_latach %}
        {% include "browse/tytul_raportu.html" with obj=jednostka %}
        <input class="submit button" type="submit" value="Szukaj"/>
    </form>

{% endblock %}
