# Generated by Django 3.0.11 on 2021-02-28 16:39

import django.contrib.postgres.fields
import taggit.managers
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("taggit", "0003_taggeditem_add_unique_index"),
        ("bpp", "0239_egeria_import_new_autor_flds"),
    ]

    operations = [
        migrations.CreateModel(
            name="SlowaKluczoweView",
            fields=[
                (
                    "id",
                    django.contrib.postgres.fields.ArrayField(
                        base_field=models.IntegerField(),
                        primary_key=True,
                        serialize=False,
                        size=3,
                    ),
                ),
            ],
            options={
                "db_table": "bpp_slowa_kluczowe_view",
                "managed": False,
            },
        ),
        migrations.AlterField(
            model_name="patent",
            name="slowa_kluczowe",
            field=taggit.managers.TaggableManager(
                blank=True,
                help_text="Lista słów kluczowych, oddzielonych przecinkiem.",
                through="taggit.TaggedItem",
                to="taggit.Tag",
                verbose_name="Słowa kluczowe",
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="slowa_kluczowe",
            field=taggit.managers.TaggableManager(
                blank=True,
                help_text="Lista słów kluczowych, oddzielonych przecinkiem.",
                through="taggit.TaggedItem",
                to="taggit.Tag",
                verbose_name="Słowa kluczowe",
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="slowa_kluczowe",
            field=taggit.managers.TaggableManager(
                blank=True,
                help_text="Lista słów kluczowych, oddzielonych przecinkiem.",
                through="taggit.TaggedItem",
                to="taggit.Tag",
                verbose_name="Słowa kluczowe",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="slowa_kluczowe",
            field=taggit.managers.TaggableManager(
                blank=True,
                help_text="Lista słów kluczowych, oddzielonych przecinkiem.",
                through="taggit.TaggedItem",
                to="taggit.Tag",
                verbose_name="Słowa kluczowe",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="slowa_kluczowe",
            field=taggit.managers.TaggableManager(
                blank=True,
                help_text="Lista słów kluczowych, oddzielonych przecinkiem.",
                through="taggit.TaggedItem",
                to="taggit.Tag",
                verbose_name="Słowa kluczowe",
            ),
        ),
    ]
