{% extends "base.html" %}


{% block extratitle %}
    Dodaj listę ministerialną
{% endblock %}


{% block breadcrumbs %}
    {{ block.super }}
    <li><a href="{% url "integrator2:main" %}">integrator</a></li>
    <li class="current">dodaj listę ministerialną</li>

{% endblock %}

{% block content %}
    {% load crispy_forms_tags %}
    {% crispy form %}
{#    <h1>Jak importować dane? </h1>#}
{#    <h2>Integracja autorów bez PBN ID</h2>#}
{#    Warunki przyjęcia pliku do analizy to:#}
{#    <ul>#}
{#        <li>w jednym z pierwszych wierszy musi znaleźć się nagłówek tabeli</li>#}
{#        <li>wartości nagłówka muszą nazywać się: Tytuł/Stopień, Nazwisko, Imię, Nazwa jednostki</li>#}
{#        <li>inne nagłówki kolumn, a co za tym idzie, również i wartości w tych kolumnach, zostaną zignorowane</li>#}
{#        <li>proszę <b style="color:red;">nie dodawać plików zawierających kody PESEL</b>, ponieważ kody PESEL nie są#}
{#            potrzebne do#}
{#            scalenia danych, a stanowią zagrożenie ujawnienia danych osobowych w wypadku dostępu do systemu przez#}
{#            niepowołane osoby#}
{#        </li>#}
{#        <li>plik wejściowy winien być w formacie Microsoft Excel</li>#}
{#    </ul>#}
{#    <h2>Integracja autorów</h2>#}
{#    <ul>#}
{#        <li>wartości nagłówka muszą nazywać się: Tytuł/Stopień, Nazwisko, Imię, Nazwa jednostki, PBN ID</li>#}
{#        <li>pozostałe warunki jak w "Integracja autorów bez PBN ID"</li>#}
{#    </ul>#}

{% endblock %}