# Generated by Django 3.0.14 on 2021-05-19 00:37

from django.db import migrations

import bpp.models.dyscyplina_naukowa
import bpp.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0266_auto_20210519_0236"),
    ]

    operations = [
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_liczbe_cytowan_na_stronie_autora",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="always",
                help_text="Liczba cytowań będzie wyświetlana, gdy większa od 0",
                max_length=50,
                verbose_name="Pokazuj liczbę cytowań na podstronie autora",
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_liczbe_cytowan_w_rankingu",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="always",
                max_length=50,
                verbose_name="Pokazuj liczbę cytowań w rankingu",
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_praca_recenzowana",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="always",
                max_length=50,
                verbose_name='Pokazuj opcję "Praca recenzowana"',
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_ranking_autorow",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="always",
                max_length=50,
                verbose_name="Pokazuj ranking autorów",
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_raport_autorow",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="always",
                max_length=50,
                verbose_name="Pokazuj raport autorów",
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_raport_dla_komisji_centralnej",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="always",
                max_length=50,
                verbose_name="Pokazuj raport dla Komisji Centralnej",
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_raport_jednostek",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="logged-in",
                max_length=50,
                verbose_name="Pokazuj raport jednostek",
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_raport_slotow_autor",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="logged-in",
                max_length=50,
                verbose_name="Pokazuj raport slotów - autor",
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_raport_slotow_uczelnia",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="logged-in",
                max_length=50,
                verbose_name="Pokazuj raport slotów - uczelnia",
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_raport_slotow_zerowy",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="logged-in",
                max_length=50,
                verbose_name="Pokazuj raport slotów zerowy",
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_raport_wydzialow",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="logged-in",
                max_length=50,
                verbose_name="Pokazuj raport wydziałów",
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_status_korekty",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="always",
                max_length=50,
                verbose_name="Pokazuj status korekty na stronie rekordu",
            ),
        ),
        migrations.AlterField(
            model_name="uczelnia",
            name="pokazuj_tabele_slotow_na_stronie_rekordu",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("staff", "tylko dla zespołu"),
                    ("never", "nigdy"),
                ],
                default="logged-in",
                max_length=50,
                verbose_name="Pokazuj tabelę slotów na stronie rekordu",
            ),
        ),
    ]
