# Generated by Django 3.0.14 on 2021-10-28 01:41

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0033_sent_data_typ_rekordu"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="publication",
            options={
                "verbose_name": "Publikacja z PBN API",
                "verbose_name_plural": "Publikacje z PBN API",
            },
        ),
        migrations.AddField(
            model_name="oswiadczenieinstytucji",
            name="statedTimestamp",
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="sentdata",
            name="pbn_uid",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="pbn_api.Publication",
                verbose_name="Publikacja z PBN",
            ),
        ),
    ]
