# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-14 15:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0122_import_dyscyplin'),
    ]

    operations = [
        migrations.AddField(
            model_name='dyscyplina_naukowa',
            name='kod',
            field=models.CharField(blank=True, max_length=20, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='dyscyplina_naukowa',
            name='nazwa',
            field=models.CharField(max_length=200, unique=True),
        ),
    ]
