# Generated by Django 2.1.13 on 2019-11-07 07:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0191_wydawnictwo_zwarte_zewnetrzna_baza_danych'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='dyscyplina_naukowa',
            name='dyscyplina_nadrzedna',
        ),
        migrations.RemoveField(
            model_name='dyscyplina_naukowa',
            name='level',
        ),
        migrations.RemoveField(
            model_name='dyscyplina_naukowa',
            name='lft',
        ),
        migrations.RemoveField(
            model_name='dyscyplina_naukowa',
            name='rght',
        ),
        migrations.RemoveField(
            model_name='dyscyplina_naukowa',
            name='tree_id',
        ),
        migrations.AlterField(
            model_name='dyscyplina_naukowa',
            name='kod',
            field=models.CharField(default='0.00', max_length=20, unique=True),
            preserve_default=False,
        ),
    ]
