# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-16 11:03
from __future__ import unicode_literals

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0127_auto_20180416_1303'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0128_zewnetrzne_bazy_view")
        ),
    ]
