# Generated by Django 3.0.9 on 2020-08-12 17:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("bpp", "0222_auto_20200812_1927"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="grant_rekordu",
            options={
                "verbose_name": "grant rekordu",
                "verbose_name_plural": "granty rekordu",
            },
        ),
        migrations.AlterUniqueTogether(
            name="grant_rekordu",
            unique_together={("grant", "content_type", "object_id")},
        ),
    ]
