# Generated by Django 2.2.10 on 2020-02-23 12:39

import bpp.models.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0195_cc0"),
    ]

    operations = [
        migrations.AddField(
            model_name="uczelnia",
            name="pokazuj_raport_slotow_zerowy",
            field=bpp.models.fields.OpcjaWyswietlaniaField(
                choices=[
                    ("always", "zawsze"),
                    ("logged-in", "tylko dla zalogowanych"),
                    ("never", "nigdy"),
                ],
                default="logged-in",
                max_length=50,
                verbose_name="Pokazuj raport slotów zerowy",
            ),
        ),
    ]
