{% extends "base.html" %}

{% block extrahead %}
    {{ block.super }}
    <meta http-equiv="refresh" content="30">
{% endblock %}

{% block content %}
    Oczekiwanie na rozpoczęcie przetwarzania...
{% endblock %}
