# Generated by Django 3.0.14 on 2021-11-09 23:00

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0309_auto_20211110_0000"),
        ("ewaluacja2021", "0005_auto_20211028_0039"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="importmaksymalnychslotow",
            options={"ordering": ("-ostatnia_zmiana",)},
        ),
        migrations.CreateModel(
            name="ZamowienieNaRaport",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "rodzaj",
                    models.CharField(
                        choices=[
                            ("plecakowy", "plecakowy"),
                            ("genetyczny", "genetyczny"),
                        ],
                        max_length=20,
                        verbose_name="Rodzaj algorytmu",
                    ),
                ),
                ("uid_zadania", models.TextField(blank=True, null=True)),
                ("plik_wyjsciowy", models.FileField(upload_to="")),
                ("wykres_wyjsciowy", models.ImageField(upload_to="")),
                ("ostatnio_zmodyfikowany", models.DateTimeField(auto_now=True)),
                (
                    "dyscyplina_naukowa",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="bpp.Dyscyplina_Naukowa",
                    ),
                ),
            ],
        ),
    ]
