# Generated by Django 2.1.10 on 2019-10-13 21:24

import bpp.models.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0181_cache_punktacja_autora_sum_cache_punktacja_autora_sum_gruop'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='uczelnia',
            name='pokazuj_raport_slotow',
        ),
        migrations.AddField(
            model_name='uczelnia',
            name='pokazuj_raport_slotow_autor',
            field=bpp.models.fields.OpcjaWyswietlaniaField(choices=[('always', 'zawsze'), ('logged-in', 'tylko dla zalogowanych'), ('never', 'nigdy')], default='logged-in', max_length=50, verbose_name='Pokazuj raport slotów - autor'),
        ),
        migrations.AddField(
            model_name='uczelnia',
            name='pokazuj_raport_slotow_uczelnia',
            field=bpp.models.fields.OpcjaWyswietlaniaField(choices=[('always', 'zawsze'), ('logged-in', 'tylko dla zalogowanych'), ('never', 'nigdy')], default='logged-in', max_length=50, verbose_name='Pokazuj raport slotów - uczelnia'),
        ),
    ]
