{% extends "base.html" %}
{% load humanize static %}

{% block extratitle %}
    Import udziałów dla autorów
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li><a href="..">import udziałów dla autorów</a></li>
    <li class="current">nowy import</li>
{% endblock %}

{% block content %}
    <h2>Utwórz nowy import</h2>
        {% load crispy_forms_tags %}
    {% crispy form %}

{% endblock %}
