# Generated by Django 3.0.14 on 2021-10-03 20:39

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0301_doktorska_habilitacyjna_denorm"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql(
                "0302_denorm_autor_dyscyplina_new_trigger"
            )
        ),
    ]
