# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-06-12 22:07
from __future__ import unicode_literals

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0148_charakter_formalny_nadrzedny'),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0149_ranking_afiliacje")
        )
    ]
