# Generated by Django 3.0.14 on 2021-05-03 22:11

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0266_auto_20210504_0040"),
    ]

    operations = [
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0265_rekord_mat_doi", app_name="bpp"),
        ),
        # Odbudowanie tabeli rekord_mat spowoduje skasowanie bpp_uczelnia_ewaluacja_view,
        # stąd potrzeba zaciągnąć ten plik z poprzednich migracji:
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0207_uczelnia_analiza_view")
        ),
    ]
