    {% if uczelnia.wydruk_logo %}
        <table class="show-for-print" border="0" style="border:none !important;" cellpadding="0" cellspacing="0">
            <tr>
                <td><img width="{{ uczelnia.wydruk_logo_szerokosc }}"
                         src="/media/{{ uczelnia.logo_www }}"
                         alt="Logo {{ uczelnia.nazwa_dopelniacz }}"
                /></td>
                <td><h4>Bibliografia Publikacji Pracowników<br/>
                    {{ uczelnia.nazwa_dopelniacz }}</h4></td>
            </tr>
        </table>
    {% endif %}

