{% extends "base.html" %}

{% block extratitle %}
    Wylogowano
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li class="current">Wylogowano</a>
{% endblock %}

{% block content %}
    Wylogowano pomyślnie, dziekuję!
{% endblock %}
