# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-19 09:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0089_legacy_data'),
    ]

    operations = [
        migrations.AddField(
            model_name='patent',
            name='pbn_id',
            field=models.IntegerField(blank=True, db_index=True, help_text='Identyfikator w systemie Polskiej Bibliografii Naukowej (PBN)', null=True, unique=True, verbose_name='Identyfikator PBN'),
        ),
        migrations.AddField(
            model_name='praca_doktorska',
            name='pbn_id',
            field=models.IntegerField(blank=True, db_index=True, help_text='Identyfikator w systemie Polskiej Bibliografii Naukowej (PBN)', null=True, unique=True, verbose_name='Identyfikator PBN'),
        ),
        migrations.AddField(
            model_name='praca_habilitacyjna',
            name='pbn_id',
            field=models.IntegerField(blank=True, db_index=True, help_text='Identyfikator w systemie Polskiej Bibliografii Naukowej (PBN)', null=True, unique=True, verbose_name='Identyfikator PBN'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='pbn_id',
            field=models.IntegerField(blank=True, db_index=True, help_text='Identyfikator w systemie Polskiej Bibliografii Naukowej (PBN)', null=True, unique=True, verbose_name='Identyfikator PBN'),
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='pbn_id',
            field=models.IntegerField(blank=True, db_index=True, help_text='Identyfikator w systemie Polskiej Bibliografii Naukowej (PBN)', null=True, unique=True, verbose_name='Identyfikator PBN'),
        ),
    ]
