# Generated by Django 2.1.10 on 2019-10-30 06:06

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0190_auto_20191030_0532'),
    ]

    operations = [
        migrations.CreateModel(
            name='Wydawnictwo_Zwarte_Zewnetrzna_Baza_Danych',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('info', models.CharField(blank=True, max_length=512, null=True, verbose_name='Informacje dodatkowe')),
                ('baza', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Zewnetrzna_Baza_Danych')),
                ('rekord', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='zewnetrzna_baza_danych', to='bpp.Wydawnictwo_Zwarte')),
            ],
            options={
                'verbose_name': 'powiązanie wydawnictwa zwartego z zewnętrznymi bazami danych',
                'verbose_name_plural': 'powiązania wydawnictw zwartych z zewnętrznymi bazami danych',
            },
        ),
    ]
