# Generated by Django 3.0.14 on 2021-10-28 00:57

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0306_delete_ewaluacja2021liczbandlauczelni"),
    ]

    operations = [
        migrations.CreateModel(
            name="Wydawnictwo_Zwarte_Streszczenie",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("streszczenie", models.TextField(blank=True, null=True)),
                (
                    "jezyk_streszczenia",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="bpp.Jezyk",
                    ),
                ),
                (
                    "rekord",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="bpp.Wydawnictwo_Zwarte",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="Wydawnictwo_Ciagle_Streszczenie",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("streszczenie", models.TextField(blank=True, null=True)),
                (
                    "jezyk_streszczenia",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to="bpp.Jezyk",
                    ),
                ),
                (
                    "rekord",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to="bpp.Wydawnictwo_Ciagle",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
    ]
