# Generated by Django 3.0.14 on 2021-05-19 00:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0265_rekord_mat_doi"),
    ]

    operations = [
        migrations.AddField(
            model_name="autor",
            name="pokazuj_poprzednie_nazwiska",
            field=models.BooleanField(
                default=True,
                help_text="Jeżeli odznaczone, poprzednie nazwiska nie będą się wyświetlać na podstronie autora dla użytkowników niezalogowanych. Użytkownicy zalogowani widzą je zawsze. Wyszukiwanie po poprzednich nazwiskach będzie nadal możliwe. ",
            ),
        ),
    ]
