# Generated by Django 3.0.14 on 2021-08-16 06:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("pbn_api", "0025_auto_20210809_0149"),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name="oswiadczenieinstytucji",
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name="publikacjainstytucji",
            unique_together=set(),
        ),
    ]
