# Generated by Django 2.1.7 on 2019-08-24 07:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0174_rodzaj_pbn_dla_charakteru'),
        ('bpp', '0174_uczelnia_podpowiadaj_dyscypliny_konfig'),
    ]

    operations = [
    ]
