# Generated by Django 3.0.14 on 2021-09-24 17:39

from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("rozbieznosci_dyscyplin", "0010_recreate"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="rozbieznosciview",
            options={
                "managed": False,
                "verbose_name": "rozbieżność rekordu i dyscyplin",
                "verbose_name_plural": "rozbieżności rekordów i dyscyplin",
            },
        ),
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql(
                "0011_null_is_wrong", app_name="rozbieznosci_dyscyplin"
            )
        ),
    ]
