# Generated by Django 3.2.15 on 2022-08-16 15:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("zglos_publikacje", "0008_auto_20220816_1255"),
    ]

    operations = [
        migrations.AlterField(
            model_name="zgloszenie_publikacji",
            name="status",
            field=models.PositiveSmallIntegerField(
                choices=[
                    (0, "nowe zgłoszenie"),
                    (1, "zaakceptowany - dodany do bazy BPP"),
                    (2, "wymaga zmian - odesłano do zgłaszającego"),
                    (3, "zmiany naniesione przez zgłaszającego"),
                    (4, "odrzucono w całości"),
                    (5, "spam"),
                ],
                default=0,
            ),
        ),
    ]
