{% extends "admin/change_form.html" %}

{% block submit_buttons_bottom %}
    {{ block.super }}
    <script type="text/javascript">
        (function($) {
            pub_id = $("#id_autorzy_set-__prefix__-rekord").val()

            if (pub_id) {
                btn = $("input[name=_continue]");
                tamze = $("<input/>")
                    .attr("id", "tamze")
                    .attr("class", "grp-button")
                    .attr("type", "button")
                    .attr("value", "Tamże");

                toz = tamze.clone()
                    .attr("id", "toz")
                    .attr("value", "Toż");

                btn.parent().parent().append($("<li/>").append(tamze));
                btn.parent().parent().append($("<li/>").append(toz));

                $("#tamze").click(function () {
                    data = {
                        "informacje": $("textarea[name=informacje]").val(),
                        "uwagi": $("textarea[name=uwagi]").val(),
                        "rok": $("input[name=rok]").val(),

                        "punkty_kbn": $("input[name=punkty_kbn]").val(),
                        "impact_factor": $("input[name=impact_factor]").val(),
                        "index_copernicus": $("input[name=index_copernicus]").val(),
                        "punktacja_wewnetrzna": $("input[name=punktacja_wewnetrzna]").val(),

                        "kc_punkty_kbn": $("input[name=kc_punkty_kbn]").val(),
                        "kc_impact_factor": $("input[name=kc_impact_factor]").val(),
                        "kc_index_copernicus": $("input[name=kc_index_copernicus]").val()
                    }

                    location.href = "../../add/?" + $.param(data);
                });

                $("#toz").click(function () {
                    if (confirm('Utworzysz kopię tego rekordu. Czy kontynuować?')) {
                        location.href = "../../toz/" + pub_id;
                    }
                });
            }
        }(django.jQuery));
    </script>
{% endblock %}