# Generated by Django 3.0.11 on 2021-01-03 11:52

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0232_auto_20210101_1751"),
    ]

    operations = [
        migrations.AlterField(
            model_name="praca_doktorska",
            name="autor",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE, to="bpp.Autor"
            ),
        ),
    ]
