# Generated by Django 3.2.14 on 2022-07-07 22:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("import_list_if", "0002_auto_20210308_1246"),
    ]

    operations = [
        migrations.AlterField(
            model_name="importlistifrow",
            name="dane_z_xls",
            field=models.JSONField(),
        ),
    ]
