{% extends "base.html" %}{% load render_table from django_tables2 %}

{% block extratitle %}
    Import pracowników - szczegóły {{ object.plik_xls.name }}
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li><a href="{% url "import_pracownikow:index" %}">import pracowników</a></li>
    <li class="current">import {{ object.plik_xls.name }}</li>
{% endblock %}


{% block content %}
    <h1>Import danych {{ object.plik_xls.name }}</h1>

    {% include "long_running/operation_details.html" %}

{% endblock %}
