# Generated by Django 3.0.7 on 2020-07-27 22:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0219_auto_20200727_2308"),
    ]

    operations = [
        migrations.AlterField(
            model_name="grant",
            name="numer_projektu",
            field=models.CharField(max_length=200, unique=True),
        ),
    ]
