# Generated by Django 3.0.11 on 2021-02-23 21:28

import taggit.managers
from django.db import migrations

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ("taggit", "0003_taggeditem_add_unique_index"),
        ("bpp", "0236_merge_20210202_0850"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="patent",
            name="slowa_kluczowe",
        ),
        migrations.AddField(
            model_name="patent",
            name="slowa_kluczowe",
            field=taggit.managers.TaggableManager(
                help_text="A comma-separated list of tags.",
                through="taggit.TaggedItem",
                to="taggit.Tag",
                verbose_name="Słowa kluczowe",
            ),
        ),
        migrations.RemoveField(
            model_name="praca_doktorska",
            name="slowa_kluczowe",
        ),
        migrations.AddField(
            model_name="praca_doktorska",
            name="slowa_kluczowe",
            field=taggit.managers.TaggableManager(
                help_text="A comma-separated list of tags.",
                through="taggit.TaggedItem",
                to="taggit.Tag",
                verbose_name="Słowa kluczowe",
            ),
        ),
        migrations.RemoveField(
            model_name="praca_habilitacyjna",
            name="slowa_kluczowe",
        ),
        migrations.AddField(
            model_name="praca_habilitacyjna",
            name="slowa_kluczowe",
            field=taggit.managers.TaggableManager(
                help_text="A comma-separated list of tags.",
                through="taggit.TaggedItem",
                to="taggit.Tag",
                verbose_name="Słowa kluczowe",
            ),
        ),
        migrations.RemoveField(
            model_name="wydawnictwo_ciagle",
            name="slowa_kluczowe",
        ),
        migrations.AddField(
            model_name="wydawnictwo_ciagle",
            name="slowa_kluczowe",
            field=taggit.managers.TaggableManager(
                help_text="A comma-separated list of tags.",
                through="taggit.TaggedItem",
                to="taggit.Tag",
                verbose_name="Słowa kluczowe",
            ),
        ),
        migrations.RemoveField(
            model_name="wydawnictwo_zwarte",
            name="slowa_kluczowe",
        ),
        migrations.AddField(
            model_name="wydawnictwo_zwarte",
            name="slowa_kluczowe",
            field=taggit.managers.TaggableManager(
                help_text="A comma-separated list of tags.",
                through="taggit.TaggedItem",
                to="taggit.Tag",
                verbose_name="Słowa kluczowe",
            ),
        ),
        #
        # Powyższe operacje wywołają skasowanie tabeli bpp_rekord_mat
        #
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0237_rekord_mat_slowa_kluczowe")
        ),
        # Odbudowanie tabeli rekord_mat spowoduje skasowanie bpp_uczelnia_ewaluacja_view,
        # stąd potrzeba zaciągnąć ten plik z poprzednich migracji:
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0207_uczelnia_analiza_view")
        ),
    ]
