# Generated by Django 3.0.7 on 2020-07-27 21:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0216_element_repozytorium"),
    ]

    operations = [
        migrations.CreateModel(
            name="Grant",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("nazwa_projektu", models.TextField(blank=True, null=True)),
                ("zrodlo_finansowania", models.TextField(blank=True, null=True)),
                ("numer_projektu", models.CharField(max_length=200)),
                ("rok", models.PositiveSmallIntegerField()),
            ],
        ),
    ]
