<div class="ui-widget">
    <div class="ui-state-error ui-corner-all" style="padding: 0 .7em;">
        <p><span class="ui-icon ui-icon-alert"
                 style="float: left; margin-right: .7em;"></span>
            <strong>Błąd:</strong> {{ message }} </p>
    </div>
</div>