{% extends "admin/change_form.html" %}{% load i18n %}

{% block object-tools-items %}
    {% if original.template.pk %}
        <li><a href="/admin/dbtemplates/template/{{ original.template.pk }}/change/">Edycja szablonu</a></li>
    {% endif %}
    {{ block.super }}
{% endblock %}
