# Generated by Django 3.2.14 on 2022-07-07 22:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0323_jednostka_pokazuj_opis"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Kronika_Patent_View",
        ),
        migrations.DeleteModel(
            name="Kronika_Praca_Doktorska_View",
        ),
        migrations.DeleteModel(
            name="Kronika_Praca_Habilitacyjna_View",
        ),
        migrations.DeleteModel(
            name="Kronika_View",
        ),
        migrations.DeleteModel(
            name="Kronika_Wydawnictwo_Ciagle_View",
        ),
        migrations.DeleteModel(
            name="Kronika_Wydawnictwo_Zwarte_View",
        ),
        migrations.AlterField(
            model_name="autor",
            name="orcid_w_pbn",
            field=models.BooleanField(
                help_text="Jeżeli ORCID jest w bazie PBN, to pole powinno być zaznaczone. Zaznaczenie następuje\n        automatycznie, przez procedury integrujące bazę danych z PBNem w nocy. Można też zaznaczyć ręcznie.\n        Pole wykorzystywane jest gdy autor nie ma odpowiednika w PBN (pole 'PBN UID' rekordu autora jest puste,\n        zaś eksport danych powoduje komunikat zwrotny z PBN o nieistniejącym w ich bazie ORCID). W takich sytuacjach\n        należy w polu wybrać \"Nie\". ",  # noqa
                null=True,
                verbose_name="ORCID jest w bazie PBN?",
            ),
        ),
        migrations.AlterField(
            model_name="autor_jednostka",
            name="podstawowe_miejsce_pracy",
            field=models.BooleanField(null=True),
        ),
        migrations.AlterField(
            model_name="bppuser",
            name="first_name",
            field=models.CharField(
                blank=True, max_length=150, verbose_name="first name"
            ),
        ),
        migrations.AlterField(
            model_name="patent",
            name="cached_punkty_dyscyplin",
            field=models.JSONField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name="patent",
            name="wdrozenie",
            field=models.BooleanField(null=True, verbose_name="Wdrożenie"),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Publikacja bezkosztowa"),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne środki finansowe"),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                help_text="Środki finansowe przyznane na realizację projektu w zakresie badań naukowych lub prac rozwojowych",  # noqa
                null=True,
                verbose_name="Środki finansowe na realizację projektu",
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                help_text="Środki finansowe, o których mowa w art. 365 pkt 2 ustawy",
                null=True,
                verbose_name="Środki finansowe art. 365 pkt 2 ustawy",
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Publikacja bezkosztowa"),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne środki finansowe"),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                help_text="Środki finansowe przyznane na realizację projektu w zakresie badań naukowych lub prac rozwojowych",  # noqa
                null=True,
                verbose_name="Środki finansowe na realizację projektu",
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                help_text="Środki finansowe, o których mowa w art. 365 pkt 2 ustawy",
                null=True,
                verbose_name="Środki finansowe art. 365 pkt 2 ustawy",
            ),
        ),
        migrations.AlterField(
            model_name="wydawca",
            name="lista_poziomow",
            field=models.JSONField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="cached_punkty_dyscyplin",
            field=models.JSONField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Publikacja bezkosztowa"),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne środki finansowe"),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                help_text="Środki finansowe przyznane na realizację projektu w zakresie badań naukowych lub prac rozwojowych",  # noqa
                null=True,
                verbose_name="Środki finansowe na realizację projektu",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                help_text="Środki finansowe, o których mowa w art. 365 pkt 2 ustawy",
                null=True,
                verbose_name="Środki finansowe art. 365 pkt 2 ustawy",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="cached_punkty_dyscyplin",
            field=models.JSONField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Publikacja bezkosztowa"),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne środki finansowe"),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                help_text="Środki finansowe przyznane na realizację projektu w zakresie badań naukowych lub prac rozwojowych",  # noqa
                null=True,
                verbose_name="Środki finansowe na realizację projektu",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                help_text="Środki finansowe, o których mowa w art. 365 pkt 2 ustawy",
                null=True,
                verbose_name="Środki finansowe art. 365 pkt 2 ustawy",
            ),
        ),
    ]
