{% extends "base.html" %}

{% block extratitle %}
    {{ title }}
{% endblock %}

{% block breadcrumbs %}
    {{ block.super }}
    <li class="current">{{ title }}</li>
{% endblock %}

{% block content %}
    <h2>{{ title }}</h2>
    {# go_to_admin_change.html #}
    {% load user_in_group %}{% if request.user.is_superuser or request.user|has_group:"raporty" %}
        <div class="callout warning hide-for-print">
            <a target="_blank" href="{% url "admin:flexible_reports_report_change" report.pk %}">
                <i class="fi-page-edit"></i>
                {{ text|default:"otwórz do edycji" }}</a>
        </div>
    {% endif %}
    <div class="grid-x">
        <div class="large-8 medium-12 small-12 cell">
            {% load crispy_forms_tags %}
            {% crispy form %}
        </div>
    </div>
{% endblock %}