# Generated by Django 3.0.11 on 2021-03-08 07:46

from decimal import Decimal

import django.core.validators
from django.db import migrations, models

import bpp.models.uczelnia


class Migration(migrations.Migration):

    dependencies = [
        ("raport_slotow", "0008_auto_20210308_0839"),
    ]

    operations = [
        migrations.AlterField(
            model_name="raportslotowuczelnia",
            name="akcja",
            field=models.CharField(
                choices=[
                    (
                        "slot",
                        "zbieraj najkorzystniejsze prace do zadanej wielkości slotu",
                    ),
                    ("wszystko", "wyeksportuj wszystkie prace"),
                ],
                default="slot",
                max_length=10,
            ),
        ),
        migrations.AlterField(
            model_name="raportslotowuczelnia",
            name="do_roku",
            field=models.IntegerField(
                default=bpp.models.uczelnia.UczelniaManager.do_roku_default
            ),
        ),
        migrations.AlterField(
            model_name="raportslotowuczelnia",
            name="slot",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                default=Decimal("1"),
                max_digits=7,
                null=True,
                validators=[django.core.validators.MaxValueValidator(20)],
            ),
        ),
    ]
