# Generated by Django 3.0.11 on 2021-02-28 12:41

import uuid

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models

import long_running.models
import long_running.notification_mixins


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="ImportPracownikow",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("created_on", models.DateTimeField(auto_now_add=True)),
                ("last_updated_on", models.DateTimeField(auto_now=True)),
                ("started_on", models.DateTimeField(blank=True, null=True)),
                ("finished_on", models.DateTimeField(blank=True, null=True)),
                ("finished_successfully", models.BooleanField(default=False)),
                ("traceback", models.TextField(blank=True, null=True)),
                ("plik_xls", models.FileField(upload_to="")),
                (
                    "owner",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "ordering": ["-last_updated_on"],
                "abstract": False,
            },
            bases=(
                long_running.notification_mixins.ASGINotificationMixin,
                long_running.models.NullNotificationMixin,
                models.Model,
            ),
        ),
    ]
